'use strict'

var app = angular.module('GymStarApp.controllers', ['ionic', 'ngResource']);

app.controller('LoginCtrl', function($scope, $http, $state, $rootScope, $ionicHistory, $ionicModal, AuthService, $timeout, ErrorHandler, $localStorage, $cordovaDialogs, $ionicLoading, UserDataService, workoutService, Constants, $cordovaToast) {
    var baseUrl = Constants.API.baseUrl;
    var serviceUrl = Constants.API.serviceUrl;
    var tokenUrl = Constants.API.tokenUrl;
    var loginUrl = Constants.API.loginUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    $scope.loginFailure = 0;

    $ionicModal.fromTemplateUrl('m-forgottenpassword.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function(modal) {
        $scope.modal = modal;
    });

    $scope.$on('$destroy', function() {
        $scope.modal.remove();
    })

    $scope.login = function(user) {
        if (!user.username || !user.password) {
            if (user.username) alertPopup("Please input password!");
            else if (user.password) alertPopup("Please input username!");
            else alertPopup("Please input username and password!");
        } else {
            var user_login = {
                username: user.username,
                password: user.password
            };
            $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner><p>Please wait...</p>',
                duration: CONSTANT_TIMEOUT
            });
            $http.get(tokenUrl, {
                timeout: CONSTANT_TIMEOUT
            }).then(function(resp) {
                $localStorage.csrftoken = resp.data;
                $http.post(loginUrl, user_login, {
                    timeout: CONSTANT_TIMEOUT
                }).then(function(response) {
                    $localStorage.$reset();
                    $localStorage.session = response.data.session_name + "=" + response.data.sessid;
                    $localStorage.csrftoken = response.data.token;
                    var displayUser = UserDataService.displayUser(response.data.user);
                    $localStorage.loginuser = displayUser;
                    $localStorage.teams = response.data.teams;
                    AuthService.init();
                    //AuthService.register();
                    $ionicLoading.hide();
                    $ionicHistory.clearCache();
                    if (displayUser.privacy == 2) {
                        $state.go('tabs.myprofile');
                    } else {
                        $state.go('tabs.livefeed');
                    }
                }, function(error) {
                    $ionicLoading.hide();
                    if (error.status === 406) //406 error
                    {
                        if (error.statusText.indexOf("Already logged in") > -1) {
                            $ionicHistory.clearCache();
                            $state.go('tabs.livefeed');
                        } else if (error.statusText.indexOf("Account is temporarily blocked") > -1) {
                            ErrorHandler.alertPopup("Your account is locked, please contact the customer service.");
                        }
                    } else {
                        if (error.status === 401 && error.statusText.indexOf("Wrong username or password.") > -1) {
                            $scope.loginFailure++;
                            var _msg = "Incorrect username or password."
                            if ($scope.loginFailure >= 3 & $scope.loginFailure < 5) {
                                var _try = 6 - parseInt($scope.loginFailure);
                                _msg = _msg + " you are allowed " + _try + " more attempts before your account is locked.";
                            } else if ($scope.loginFailure === 5) {
                                _msg = _msg + " you are allowed one more attempt before your account is locked.";
                            }
                            ErrorHandler.alertPopup(_msg);
                        } else {
                            ErrorHandler.errorHandler(error);
                        }
                    }
                });
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.showToast = function(_user) {
        var _post_data = {};
        _post_data['name'] = _user.email;
        _post_data['firstname'] = _user.firstname;
        _post_data['lastname'] = _user.lastname;
        _post_data['dob'] = moment(_user.dob).format('YYYY-MM-DD') + " 00:00:00";

        $http.post(serviceUrl + '/user/request_new_password', _post_data, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            $cordovaToast.showShortCenter('An email has been sent to you');
            $timeout(function() {
                $cordovaProgress.hide();
                $state.go('signin');
            }, 1000);
        }, function(error) {
            ErrorHandler.errorHandler(error);
        });
    };
});

app.controller('SignUpCtrl', function($scope, $http, $localStorage, $ionicHistory, $timeout, ErrorHandler, $state, UserDataService, Constants, $cordovaDialogs, $cordovaOauth, $cordovaOauthUtility) {
    var tokenUrl = Constants.API.tokenUrl;
    var registerUrl = Constants.API.registerUrl;
    var CONSTANT_TIMEOUT = Constants.timeout;
    if ($localStorage.user) $scope.user = $localStorage.user;
    else $scope.user = {};
    $scope.countries = Constants.countryList;
    $scope.selectedCountry = $scope.countries[196];

    $scope.signup = function(user) {
        if (!user || !user.email || !user.username || !user.password) {
            ErrorHandler.alertPopup("Please Input Username, Password and Email!");
        } else {
            var data = {
                name: user.username,
                mail: user.email,
                pass: user.password
            };

            UserDataService.setUser(data);
            $localStorage.user = $scope.user;
            $http.get(tokenUrl, {
                timeout: CONSTANT_TIMEOUT
            }).then(function(resp) {
                $localStorage.csrftoken = resp.data;
                $http.post(registerUrl, data, {
                    timeout: CONSTANT_TIMEOUT
                }).then(function(response) {
                    //only for username and email validation
                }, function(error) {
                    if (error.status === 406) //406 error
                    {
                        var resText = error.statusText;
                        var errorMsg = "";
                        if (resText.indexOf("Username") > -1 || resText.indexOf("address") > -1 || resText.indexOf("is already") > -1 || resText.indexOf("Password field is required") > -1 || resText.indexOf("Your password has not met the following requirement") > -1) {
                            //$scope.errorMsg=resText;
                            if (resText.indexOf("Username field is required") > -1) //Username field is required.
                            {
                                errorMsg = errorMsg + "Username field is required. \n";
                            }
                            if (resText.indexOf("The name " + user.username + " is already taken.") > -1) //Username is taken.
                            {
                                errorMsg = errorMsg + " The username is already registered. \n";
                            }
                            if (resText.indexOf("The e-mail address " + user.email + " is already") > -1) //Username is taken.
                            {
                                errorMsg = errorMsg + " The e-mail address is already registered. \n";
                            }
                            if (resText.indexOf("E-mail address field is required") > -1) //E-mail address field is required.
                            {
                                errorMsg = errorMsg + " E-mail address field is required. \n";
                            }
                            if (resText.indexOf("The e-mail address " + user.email + " is not valid.") > -1) //E-mail address validation.
                            {
                                errorMsg = errorMsg + " E-mail address " + user.email + " is not valid.\n";
                            }
                            if (resText.indexOf("Password field is required") > -1) //Password field is required
                            {
                                errorMsg = errorMsg + " Password field is required.\n";
                            }
                            if (resText.indexOf("Your password has not met the following requirement") > -1) {
                                if (resText.indexOf("at least 2 digits") > -1) {
                                    errorMsg = errorMsg + " Password must contain at least 2 digits.\n";
                                }
                                if (resText.indexOf("Password must contain at least one letter.") > -1) {
                                    errorMsg = errorMsg + " Password must contain at least one letter.\n";
                                }
                                if (resText.indexOf("Password must not contain the username") > -1) {
                                    errorMsg = errorMsg + " Password must not contain the username.\n";
                                }
                            }

                            $timeout(function() {
                                ErrorHandler.alertPopup(errorMsg);
                            }, 500);



                        } else {
                            $state.go('personaldetails');
                        }
                    } else //other error
                    {
                        ErrorHandler.errorHandler(error);
                    }
                });
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.authenticate = function(provider) {
            if (provider == "facebook") {
                $cordovaOauth.facebook("729342917150932", ["email", "publish_actions"]).then(function(result) {
                    var fb_token = result.access_token;
                    $localStorage.fb_token = fb_token;
                    var _url = 'https://graph.facebook.com/me?access_token=' + fb_token;
                    $http.get(_url, {
                        timeout: CONSTANT_TIMEOUT
                    }).then(function(resp) {
                        if (resp.status == 200) {
                            var _resp = resp.data;
                            var _user = {};
                            _user['email'] = _resp.email;
                            _user['firstname'] = _resp.first_name;
                            _user['lastname'] = _resp.last_name;
                            _user['username'] = _resp.name;
                            var _gender = _resp.gender;
                            _user['gender'] = _gender.charAt(0).toUpperCase() + _gender.slice(1);
                            _user['facebook'] = resp.link;
                            //_resp.locale;//en_GB
                            $scope.user = _user;
                            $localStorage.user = $scope.user;
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }, function(error) {
                    alert(error);
                });
            } else if (provider == "google") {
                //https://www.googleapis.com/auth/plus.me
                //"https://www.googleapis.com/auth/userinfo.email", "https://www.googleapis.com/auth/userinfo.profile"
                $cordovaOauth.google("661231452586-8af4speedb2b4nqmohvousi05baset74.apps.googleusercontent.com", ['https://www.googleapis.com/auth/plus.me', 'https://www.googleapis.com/auth/userinfo.email']).then(function(result) {
                    var google_token = result.access_token;
                    $localStorage.google_token = google_token;
                    var _url = 'https://www.googleapis.com/plus/v1/people/me?access_token=' + google_token;
                    $http.get(_url, {
                        timeout: CONSTANT_TIMEOUT
                    }).then(function(resp) {
                        //alert(JSON.stringify(resp.data));
                        if (resp.status == 200) {
                            var _resp = resp.data;
                            var _user = {};
                            _user['email'] = _resp.emails[0].value;
                            _user['firstname'] = _resp.name.givenName;
                            _user['lastname'] = _resp.name.familyName;
                            _user['username'] = _resp.displayName;
                            var _gender = _resp.gender;
                            _user['gender'] = _gender.charAt(0).toUpperCase() + _gender.slice(1);
                            _user['google'] = _resp.url;
                            _user['towncity'] = _resp.placesLived[0].value;
                            //_resp.locale;//en_GB
                            $scope.user = _user;
                            $localStorage.user = $scope.user;
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }, function(error) {
                    ErrorHandler.errorHandler(error);
                });
            } else {
                var clientId = 'I5tbdIMOT9Y9D5s311kytRihf';
                var clientSecret = 'zBABT2V0hJwrjid3fwqzvnrVWkDgdPpapX3LfyiuU0IhxIPofm';
                $cordovaOauth.twitter(clientId, clientSecret).then(function(result) {
                    //alert(JSON.stringify(result));
                    var twitter_token = result.oauth_token;
                    var twitter_token_secret = result.oauth_token_secret;
                    $localStorage.twitter_token = result;
                    var oauthObject = {
                        oauth_consumer_key: clientId,
                        oauth_nonce: $cordovaOauthUtility.createNonce(10),
                        oauth_signature_method: "HMAC-SHA1",
                        oauth_token: result.oauth_token,
                        oauth_timestamp: Math.round((new Date()).getTime() / 1000.0),
                        oauth_version: "1.0"
                    };

                    var method = 'GET';
                    var url = 'https://api.twitter.com/1.1/account/verify_credentials.json';

                    var signatureObj = $cordovaOauthUtility.createSignature(method, url, oauthObject, {}, clientSecret, result.oauth_token_secret);

                    $http.defaults.headers.common.Authorization = signatureObj.authorization_header;

                    $http.get(url, {
                        timeout: CONSTANT_TIMEOUT
                    }).then(function(resp) {
                        if (resp.status == 200) {
                            var _resp = resp.data;
                            var _user = {};
                            //_user['email']=_resp.emails[0].value;
                            var _temp = _resp.name;
                            var _name = _temp.split(' ');
                            _user['lastname'] = _name[_name.length - 1];

                            _name.pop();
                            _name = _name.join(" ");
                            _user['firstname'] = _name;

                            _user['username'] = _resp.screen_name;

                            //_user['google']=_resp.url;
                            var _location = _resp.location
                            _location = _location.split(',');
                            _user['towncity'] = _location[0];
                            // _user['country']=_resp.status.place.country;
                            $scope.user = _user;
                            $localStorage.user = $scope.user;
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                    // results
                }, function(error) {
                    ErrorHandler.errorHandler(error);
                });
            }
        }
        //personaldetails.html handler
    $scope.detail = function(user) {
        if (user == null || user.firstname == null || user.lastname == null || user.towncity == null || $scope.selectedCountry == null || user.dob == null || user.gender == null) {
            var errorMsg = "";
            if (user == null) {
                errorMsg = "All the Information";
            } else {
                if (!user.firstname) {
                    errorMsg = errorMsg + "First Name" + ",";
                    //console.log("firstname");
                }
                if (!user.lastname) {
                    errorMsg = errorMsg + "Last Name" + ",";
                    //console.log("lastname");
                }
                if (!user.towncity) {
                    errorMsg = errorMsg + "Town" + ",";
                    //console.log("towncity");
                }
                if (!$scope.selectedCountry) {
                    errorMsg = errorMsg + "Country" + ",";
                    //console.log("country");
                }
                if (!user.dob) {
                    errorMsg = errorMsg + "DoB" + ",";
                    //console.log("dob");
                }
                if (!user.gender) {
                    errorMsg = errorMsg + "Gender" + ",";
                    //console.log("gender");
                }
                errorMsg = errorMsg.substring(0, errorMsg.length - 1);
            }
            ErrorHandler.alertPopup(errorMsg + " are required!");
        } else {
            var signupUser = UserDataService.getUser();
            signupUser["field_name_first"] = {
                'und': {
                    '0': {
                        'value': user.firstname
                    }
                }
            };
            signupUser["field_name_last"] = {
                'und': {
                    '0': {
                        'value': user.lastname
                    }
                }
            };

            signupUser["field_real_name"] = {
                'und': {
                    '0': {
                        'value': user.firstname + " " + user.lastname
                    }
                }
            };

            signupUser["field_city_town"] = {
                'und': {
                    '0': {
                        'value': user.towncity
                    }
                }
            };
            signupUser["field_country"] = {
                'und': [$scope.selectedCountry]
            };


            signupUser["field_dob"] = {
                'und': {
                    '0': {
                        'value': {
                            'date': moment(user.dob).format('YYYY-MM-DD')
                        }
                    }
                }
            };
            signupUser["field_gender"] = {
                'und': [user.gender]
            };
            if ($localStorage.user) {
                signupUser["field_facebook_url"] = {
                    'und': {
                        '0': {
                            'value': $localStorage.user.facebook
                        }
                    }
                };

            }
            UserDataService.setUser(signupUser);
            $state.go('currentstats.units');
        }
    }

    $scope.navigateTo = function(state) {
        $ionicHistory.clearCache();
        return $state.go(state);
    };
});

app.controller('SignUpFormCtrl', function($scope, $localStorage, Constants, $ionicHistory, $http, $state, UserDataService, $ionicLoading, ErrorHandler, workoutService) {
    var registerUrl = Constants.API.registerUrl;
    var loginUrl = Constants.API.loginUrl;
    var CONSTANT_TIMEOUT = Constants.timeout;
    $scope.user = {};
    /*
    //weight
    $scope.weightUnits = ["kg", "lb", "st"];
    $scope.selectedWeightUnit = $scope.weightUnits[0];
    //height
    $scope.heightUnits = ["cm", "ft"];
    $scope.selectedHeightUnit = $scope.heightUnits[0];
    //distance
    $scope.distanceUnits = ["km", "mile"];
    $scope.selectedDistanceUnit = $scope.distanceUnits[0];
    $scope.user.weightUnit = $scope.selectedWeightUnit;
    $scope.user.heightUnit = $scope.selectedHeightUnit;
    */
    $scope.user.weightUnit = "kg";
    $scope.user.heightUnit = "cm";
    $scope.user.distanceUnit = "km";

    $scope.changeWeightUnit = function(_unit) {
        $scope.user.weightUnit = _unit;
    }

    $scope.changeHeightUnit = function(_unit) {
        $scope.user.heightUnit = _unit;
    }
    $scope.changeDistanceUnit = function(_unit) {
        $scope.user.distanceUnit = _unit;
    }

    var unitExchange = function(_weightUnit, _weight) {
        if (_weightUnit == "lb") {
            _weight = _weight * 0.453592;
        } else if (_weightUnit == "st") {
            _weight = _weight * 6.35029;
        }
        return _weight.toFixed(2);
    }

    $scope.submitForm = function() {
        $ionicLoading.show({
            template: ' <ion-spinner icon="ios"></ion-spinner><p>Please wait...</p>',
            duration: CONSTANT_TIMEOUT
        });
        var signupUser = UserDataService.getUser();
        if ($scope.user) {
            var user = $scope.user;
            signupUser["field_weight_unit"] = {
                'und': [$scope.user.weightUnit]
            };
            signupUser["field_height_unit"] = {
                'und': [$scope.user.heightUnit]
            };
            var _distance = "";
            if ($scope.user.distanceUnit == "km") _distance = "m/km";
            else _distance = "mile";
            signupUser["field_distance_unit"] = {
                'und': [_distance]
            };

            var _weight = user.weight || 0;
            _weight = parseFloat(unitExchange($scope.user.weightUnit, _weight));

            var _benchpress = user.benchpress || 0;
            _benchpress = parseFloat(unitExchange($scope.user.weightUnit, _benchpress));

            var _deadlift = user.deadlift || 0;
            _deadlift = parseFloat(unitExchange($scope.user.weightUnit, _deadlift));

            var _squats = user.squats || 0;
            _squats = parseFloat(unitExchange($scope.user.weightUnit, _squats));

            var _height = user.height || 0;

            if ($scope.user.heightUnit == "ft") {
                _height = _height * 30.48;
                _height = _height.toFixed(0);
            }

            signupUser["field_weight"] = {
                'und': {
                    '0': {
                        'value': _weight
                    }
                }
            };
            signupUser["field_height"] = {
                'und': {
                    '0': {
                        'value': _height
                    }
                }
            };
            signupUser["field_body_fat"] = {
                'und': {
                    '0': {
                        'value': user.bodyfat || 0
                    }
                }
            };
            signupUser["field_restbpm"] = {
                'und': {
                    '0': {
                        'value': user.restbpm || 0
                    }
                }
            };
            signupUser["field_bench_press"] = {
                'und': {
                    '0': {
                        'value': _benchpress
                    }
                }
            };
            signupUser["field_deadlift"] = {
                'und': {
                    '0': {
                        'value': _deadlift
                    }
                }
            };

            signupUser["field_squats"] = {
                'und': {
                    '0': {
                        'value': _squats
                    }
                }
            };

            if (!user.plankmin) user.plankmin = 0;
            if (!user.planksec) user.planksec = 0;

            var _plank = user.plankmin * 60 + user.planksec;


            if (!user.onemile) user.onemile = 0;
            if (!user.onemilesec) user.onemilesec = 0;

            var _onemile = user.onemilemin * 60 + user.onemilesec;

            signupUser["field_plank"] = {
                'und': {
                    '0': {
                        'value': _plank
                    }
                }
            };
            signupUser["field_1_mile_time"] = {
                'und': {
                    '0': {
                        'value': _onemile
                    }
                }
            };
            //UserDataService.setUser(signupUser);
        }

        //signup
        $http.post(registerUrl, signupUser, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            var user_login = {
                username: signupUser.name,
                password: signupUser.pass
            }
            $http.post(loginUrl, user_login, {
                timeout: CONSTANT_TIMEOUT
            }).then(function(response) {
                $ionicLoading.hide();
                $localStorage.csrftoken = response.data.token;
                $localStorage.session = response.data.session_name + "=" + response.data.sessid;
                var displayUser = UserDataService.displayUser(response.data.user);
                $localStorage.loginuser = displayUser;
                workoutService.setUnit(displayUser.weightUnit, displayUser.distanceUnit);
                $ionicHistory.clearCache();
                delete $localStorage.user;
                $state.go('tabs.livefeed');
            }, function(error) {
                $ionicLoading.hide();
                $localStorage.$reset();
                ErrorHandler.errorHandler(error);
            });
        }, function(error) {
            if (error.status == 406) //406 error
            {
                var resText = error.statusText;
                var errorMsg = "";
                if (resText.indexOf("Username field is required") > -1) //Username field is required.
                {
                    errorMsg = errorMsg + " Username field is required.\n";
                } else if (resText.indexOf("The name " + user.username + " is already taken") > -1) //Username is taken.
                {
                    errorMsg = errorMsg + " username is already taken.\n";
                } else if (resText.indexOf("The e-mail address " + user.email + " is already taken") > -1) //Username is taken.
                {
                    errorMsg = errorMsg + " e-mail address is already taken.\n";

                } else if (resText.indexOf("E-mail address field is required") > -1) //E-mail address field is required.
                {
                    errorMsg = errorMsg + " E-mail field is required.\n";

                } else if (resText.indexOf("Password field is required") > -1) //Password field is required
                {
                    errorMsg = errorMsg + " Username field is required.\n";
                }
                ErrorHandler.alertPopup(errorMsg);
            } else {
                ErrorHandler.errorHandler(error);
            }
        });
    }
});

app.controller('NavCtrl', function($scope, $rootScope, Constants, AuthService, $ionicSideMenuDelegate, $ionicLoading, $localStorage, ErrorHandler, NotificationHandler, $ionicHistory, $state, $http) {
    var serviceUrl = Constants.API.serviceUrl;
    var socketURL = Constants.API.socketUrl;

    var user = $localStorage.loginuser;

    $scope.showMenu = function() {
        $ionicSideMenuDelegate.toggleLeft();
    };

    $scope.naviTo = function(state) {
        return $state.go(state, {}, {
            reload: true
        });
    }

    $scope.navigateTo = function(state) {
        /*
        if(displayUser.privacy==0&&state=='tabs.livefeed')
        {
            NotificationHandler.alert('Due to account setting, you could not access the livefeed').then(function(){
                 $ionicHistory.goBack();
                 //$state.go('tabs.myprofile');
             });
        }
        else if(displayUser.privacy==0&&state=='tabs.teams'){
            NotificationHandler.alert('Due to account setting, you could not access the teams').then(function(){
                 $ionicHistory.goBack();
                 //$state.go('tabs.myprofile');
             });
        }
        else
        {
            $ionicHistory.clearCache();
            return $state.go(state, {}, {
                reload: true
            });
        }*/
        $ionicHistory.clearCache();
        return $state.go(state, {}, {
            reload: true
        });
    };

    $scope.pageTo = function(state) {
        return $state.go(state);
    };

    $scope.logout = function() {
        AuthService.logout();
    }
});

app.controller('NotificationCtrl', function($scope, $http, $timeout, $state, $rootScope, $localStorage, NotificationHandler, ErrorHandler, $ionicHistory, Constants, NotificationService) {
    var serviceUrl = Constants.API.serviceUrl;
    var socketURL = Constants.API.socketUrl;
    var CONSTANT_TIMEOUT = Constants.timeout;
    var user = $localStorage.loginuser;
    var userId = user.uid;
    var _username = user.name;
    $scope.data = {};
    $scope.data.itemDelete = false;
    var localNotificaitonListener = $rootScope.$on('$gymstar:local_notification', function(event, obj) {
        $scope.notifications = $localStorage.notifications;
        $scope.$digest();
    });

    $scope.$on('$destroy', localNotificaitonListener);

    //type:
    //0: inivation to a new team
    //1: new follower (public) 
    //2: follower request (private)
    //3: receving a recommend on their workout
    //4: receving a comment on their workout
    //5: team message

    var deleteNotifi = function(_notificaiton, _index) {
        $http.get(socketURL + '/user/notification/delete/' + _username + '/' + _notificaiton.id, {
                timeout: CONSTANT_TIMEOUT
            }).then(function(response) {
                if (resposne.data) {
                    $scope.notifications.splice(_index, 1);
                    $timeout(function() {
                        $rootScope.notificationCount--;
                    }, 0);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
                //console.error('Repos error', status, data);
            });
    }

    $scope.deleteNotification = function(_notificaiton, _index) {
        if (_notificaiton.messageType == '2') {
            $http.post(serviceUrl + '/user/' + _notificaiton.uid_to + '/decline_follow/' + _notificaiton.uid_from, {},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
                if (response.status == 200) {
                    deleteNotifi(_notificaiton, _index);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else {
            deleteNotifi(_notificaiton, _index);
        }
    }

    $scope.navigateTo = function(_state, _param) {
        $ionicHistory.clearCache();
        if (_param) {
            return $state.go(_state, {
                target: _param
            });
        } else {
            return $state.go(_state);
        }
    };

    $scope.navigateToWorkout = function(_id) {
        $ionicHistory.clearCache();
        return $state.go('workout', {
            id: _id
        });

    };

    $scope.confirmFollow = function(_notificaiton, _index) {
        NotificationHandler.confirm("Do you confirm to accept this follow request?", "Confirm").then(function(btnIndex) {
            if (btnIndex == 2) { //confirm follow
                $http.post(serviceUrl + '/user/' + _notificaiton.uid_to + '/confirm_follow/' + _notificaiton.uid_from,{},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
                    if (response.status == 200) {
                        NotificationHandler.toast('request confrimed');
                        deleteNotifi(_notificaiton, _index);
                    }
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });

            }
        });
    };

    $scope.getAllNotifiction = function() {
            $http.get(socketURL + '/user/notifications/' + _username, {timeout:CONSTANT_TIMEOUT})
                .then(function(response) {
                    var success_data=response.data;
                    $scope.notifications = success_data;
                    $rootScope.notificationCount = success_data.length;
                }, function(err){
                    ErrorHandler.errorHandler(err);
                });
        }
        /*
        if ($localStorage.notifications) {
            $scope.notifications = $localStorage.notifications;
            $rootScope.notificationCount = $scope.notifications.length;
        } else {
            $scope.getAllNotifiction();
        }*/
    $scope.getAllNotifiction();
});

app.controller('FavouriteCtrl', function($scope, $localStorage, NotificationService, $timeout, $cordovaActionSheet, workoutStyle, serviceComment, NotificationHandler, $ionicLoading, $ionicModal, ErrorHandler, $ionicSideMenuDelegate, $ionicHistory, $state, $http, Constants) {
    var baseUrl = Constants.API.baseUrl;
    var IMG_PATH = Constants.API.IMG_PATH;
    var Profile_Thumbnail = Constants.API.Profile_Thumbnail;
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;

    var user = $localStorage.loginuser;
    var userId = user.uid;
    $scope.userId = userId;
    var userName = user.name;
    $scope.weightUnit = user.weightUnit;
    $scope.distanceUnit = user.distanceUnit;

    $scope.data = {};
    //Favourites
    var favouriteIndex = 0;
    $scope.data.noMoreFavouriteAvailable = true;
    $scope.favouriteList = [];
    $scope.favSummaryToggle = true;

    var loadFavourite = function(_index, _userId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration:CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/user/" + _userId + "/favourite/" + _index,{}, {timeout:CONSTANT_TIMEOUT}).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreFavouriteAvailable = true;
                else {
                    $scope.data.noMoreFavouriteAvailable = false;
                    favouriteIndex++;
                }
                var favourites = response.data;
                if (_flag) {
                    $scope.favouriteList = $scope.favouriteList.concat(favourites);
                } else $scope.favouriteList = favourites;
            } else {
                $scope.data.noMoreFavouriteAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $scope.$broadcast('scroll.refreshComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreFavourite = function() {
        loadFavourite(favouriteIndex, userId, true);
    }

    $scope.doRefresh = function() {
        loadFavourite(favouriteIndex, userId, false);
    }

    $scope.doRefresh();




    $scope.report = {};
    $scope.onHoldReport = function(_uid, _id, _type) {
        if (_uid != userId) {
            var options = {
                //addDestructiveButtonWithLabel: 'Block',
                buttonLabels: ['Report'],
                addCancelButtonWithLabel: 'Cancel',
                androidEnableCancelButton: true,
                winphoneEnableCancelButton: true
            };
            $cordovaActionSheet.show(options).then(function(btnIndex) {
                if (btnIndex == 1) report(_id, _type);
            })
        }
    }

    var report = function(_id, _type) {
        $ionicModal.fromTemplateUrl('templates/report_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.reportModal = modal;
            $scope.report.id = _id;
            $scope.report.type = _type;
            $scope.reportModal.show();
        });
    };

    $scope.closeReport = function() {
        $scope.reportModal.hide();
    }
    $scope.sendReport = function() {
        $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration:CONSTANT_TIMEOUT
        });
        var message = {};
        message['type'] = $scope.report.type
        message['tid'] = $scope.report.id;
        message['content'] = $scope.report.message;
        $http.post(serviceUrl + "/user/" + userId + "/report", message, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            $ionicLoading.hide();
            if (response.data) {
                NotificationHandler.success('Reported');
                $scope.reportModal.hide();
            }
        }, function(err) {
            $ionicLoading.hide();
            if (err.status == 406 && err.statusText.indexOf('You have already reported this content') > -1) $cordovaToast.showShortCenter(err.statusText);
            else ErrorHandler.errorHandler(err);
        });
    }


    $scope.openFullImageModal = function(_url) {
        $ionicModal.fromTemplateUrl('templates/full_image_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.fullImageModal = modal;
            $scope.fullImage = _url;
            if (window.StatusBar) {
                StatusBar.hide();
            }
            $scope.fullImageModal.show();
        });
    }

    $scope.closeFullImageModal = function() {
        $scope.fullImageModal.remove();
        if (window.StatusBar) {
            StatusBar.show();
        }
    }

    //Recommend
    $scope.data.noMoreRecommendAvailable = true;
    $scope.recommendIndex = 0;
    var loadRecommend = function(_index, _workoutId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration:CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/node/" + _workoutId + "/load_recommends/" + _index,{}, {timeout:CONSTANT_TIMEOUT}).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreRecommendAvailable = true;
                else {
                    $scope.data.noMoreRecommendAvailable = false;
                    $scope.recommendIndex++;
                }
                var recommends = response.data;
                if (_flag) {
                    $scope.recommends = $scope.recommends.concat(recommends);
                } else $scope.recommends = recommends;
            } else {
                $scope.data.noMoreRecommendAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreRecommends = function(_nid) {
        loadRecommend($scope.recommendIndex, _nid, true);
    }

    $scope.openRecommendModal = function(_nid) {
        $ionicModal.fromTemplateUrl('modal_fav_1.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_1 = modal;
            $scope.currentNID = _nid;
            loadRecommend($scope.recommendIndex, _nid, false);
            $scope.modal_1.show();
        });
    }


    //Comment
    $scope.data.shouldShowCommentDelete = false;
    $scope.data.listCommentCanSwipe = true;

    $scope.data.noMoreCommentAvailable = true;

    $scope.commentIndex = 0;
    $scope.comments = [];
    var loadComment = function(_index, _nid, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration:CONSTANT_TIMEOUT
        });
        serviceComment.query({
            'parameters[nid]': _nid,
            page: _index,
            pagesize: 20
        }).$promise.then(function(results) {
            if (results.length != 0) {
                if (results.length < 20) $scope.data.noMoreCommentAvailable = true;
                else {
                    $scope.data.noMoreCommentAvailable = false;
                    $scope.commentIndex++;
                }
                var comments = results;
                if (_flag) {
                    $scope.comments = $scope.comments.concat(comments);
                } else $scope.comments = comments;
            } else {
                $scope.data.noMoreCommentAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreComments = function(_nid) {
        loadComment($scope.commentIndex, _nid, true);
    }

    $scope.openCommentModal = function(_workout, _flag, _index) { //_flag : true open the keyboard;
        $ionicModal.fromTemplateUrl('modal_fav_2.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_2 = modal;
            $scope.currentNID = _workout.nid;
            $scope.currentIndex = _index;
            $scope.currentUID = _workout.uid;
            $scope.currentUsername = _workout.name;
            loadComment($scope.commentIndex, _workout.nid, false);
            $scope.modal_2.show();
        });
    }

    $scope.deleteComment = function(_index, _type) {
        var _cid = $scope.comments[_index].cid;
        serviceComment.remove({
            id: _cid
        }).$promise.then(function(results) {
            if (results[0]) {
                $scope.comments.splice(_index, 1);
                if (_type) { //fav
                    $scope.favouriteList[$scope.currentIndex].comment_count--;
                }
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.sendComment = function(_msg, _type) {
        var _comment = {
            "nid": $scope.currentNID,
            "name": userName,
            "comment_body": {
                "und": [{
                    "value": _msg
                }]
            }
        }
        serviceComment.post(_comment).$promise.then(function(results) {
            $scope.comments = $scope.comments.concat(results);
            if (_type) { //fav
                $scope.favouriteList[$scope.currentIndex].comment_count++;
                $scope.favouriteList[$scope.currentIndex].commented = true;
            } else {
                $scope.workoutlist[$scope.currentIndex].comment_count++;
                $scope.workoutlist[$scope.currentIndex].commented = true;
            }
            $scope.data.commentMessage = "";
            if (user.id != $scope.currentUID) {
                NotificationService.send(user.name, user.uid, $scope.currentUsername, $scope.currentUID, $scope.currentNID, 4);
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }


    $scope.closeModal = function(_id) {
        if (_id === 1) {
            $scope.modal_1.remove().then(function() {
                $scope.recommends = [];
                $scope.data.noMoreRecommendAvailable = true;
                $scope.recommendIndex = 0;
            });
        }
        if (_id === 2) {
            $scope.modal_2.remove().then(function() {
                $scope.comments = [];
                $scope.data.noMoreCommentAvailable = true;
                $scope.commentIndex = 0;
            });

        }
    }

    var favRecFunction = function(_nid, _action) {
        return $http.post(serviceUrl + '/node/' + _nid + '/' + _action, {},{timeout:CONSTANT_TIMEOUT})
    }

    $scope.favouriteClick = function(_nid, _status, _index, _type) {
        if (_status == 0) { //action, favourite
            favRecFunction(_nid, 'favourite').then(function(response) {
                if (response.status == 200) {
                    if (_type) $scope.favouriteList[_index].favourite = 1;
                    NotificationHandler.favToast(0);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unfavourite
            favRecFunction(_nid, 'unfavourite').then(function(response) {
                if (response.status == 200) {
                    if (_type) $scope.favouriteList[_index].favourite = 0;
                    NotificationHandler.favToast(1);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.recommendClick = function(_workout, _index, _type) {
        var _nid = _workout.nid;
        var _status = _workout.recommend;
        if (_status == 0) { //action, recommend
            favRecFunction(_nid, 'recommend').then(function(response) {
                if (response.status == 200) {
                    if (_type) {
                        $scope.favouriteList[_index].recommend = 1;
                        $scope.favouriteList[_index].recommends++;
                    }
                    if (user.uid != _workout.uid) {
                        NotificationService.send(user.name, user.uid, _workout.name, _workout.uid, _nid, 3);
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unrecommend
            favRecFunction(_nid, 'unrecommend').then(function(response) {
                if (response.status == 200) {
                    if (_type) {
                        $scope.favouriteList[_index].recommend = 0;
                        if ($scope.favouriteList[_index].recommends != 0) $scope.favouriteList[_index].recommends--;
                        else $scope.favouriteList[_index].recommends = 0;
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    var navTo = function(_uid) {
        if (_uid) {
            if (_uid == userId) {
                $state.go('tabs.myprofile')
            } else {
                $localStorage.fromfeed = "tabs.myprofile";
                $state.go('visitorprofile', {
                    target: _uid
                });
            }
        }
    }

    $scope.navToProfile = function(_uid, _type) {
        if (_type === 1) {
            $scope.modal_1.remove().then(function() {
                navTo(_uid);
            });
        } else if (_type === 2) {
            $scope.modal_2.remove().then(function() {
                navTo(_uid);
            });
        } else {
            navTo(_uid);
        }
    }


    $scope.rowClass = function(exercise_index, set_index, subset_length) {
        return workoutStyle.rowClass(exercise_index, set_index, subset_length);
    };
    $scope.headClass = function(exercise_index, exercises_length) {
        return workoutStyle.headClassExercise(exercise_index, exercises_length);
    };

    $scope.rowClassFirst = function(exercise_index, set_index, workout_set) {
        return workoutStyle.rowClassFirst(exercise_index, set_index, workout_set);
    };

    $scope.widthFn = function(display_type, position) {
        return workoutStyle.widthFn(display_type, position);
    };

    $scope.tableStyle = function(_index, _length) {
        return workoutStyle.tableStyle(_index, _length);
    };
});

app.controller('WelcomeCtrl', function($scope, $state, $timeout, $ionicHistory, $localStorage, $ionicLoading, Constants) {
    var CONSTANT_TIMEOUT=Constants.timeout;
    if ($localStorage.loginuser != null) {
        $ionicLoading.show({
            template: ' <ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration:CONSTANT_TIMEOUT
        });
        //io.socket.get('/user/notification/' + $localStorage.loginuser.name);
        $timeout(function() {
            $ionicLoading.hide();
            $ionicHistory.clearCache();
            if ($localStorage.loginuser.privacy == 2) {
                $state.go('tabs.myprofile');
            } else {
                $state.go('tabs.livefeed');
            }

        }, 1000);
    } else {
        $localStorage.$reset();
    }

    $scope.navigateTo = function(state) {
        return $state.go(state);
    };
});

app.controller('PBCtrl', function($http, $scope, $state, $localStorage, Constants, ErrorHandler) {
    $scope.user = $localStorage.loginuser;
    $scope.deletePB = function(_type, _index) {
        var _exercise_id = $scope.user.personalbests[_type][_index]['id'];
        $http.post(Constants.API.serviceUrl + '/user/' + $scope.user.uid + '/reset_target_pb/' + _exercise_id, {},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
            if (response.data) {
                $scope.user.personalbests[_type].splice(_index, 1);
                $localStorage.loginuser = $scope.user;
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }
});

app.controller('WorkoutCtrl', function($scope, $localStorage, $timeout, NotificationService, $stateParams, $cordovaActionSheet, workoutStyle, serviceComment, NotificationHandler, serviceWorkoutPost, $ionicLoading, $ionicModal, ErrorHandler, $ionicSideMenuDelegate, $ionicHistory, $state, $http, Constants) {
    var baseUrl = Constants.API.baseUrl;
    var IMG_PATH = Constants.API.IMG_PATH;
    var Profile_Thumbnail = Constants.API.Profile_Thumbnail;
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    var user = $localStorage.loginuser;
    var userId = user.uid;
    $scope.userId = userId;
    var userName = user.name;

    var workout_id = $stateParams.id;
    $scope.weightUnit = user.weightUnit;
    $scope.distanceUnit = user.distanceUnit;

    //Workout
    $scope.data = {};
    $scope.data.noMoreWorkoutAvailable = true;
    $scope.data.workoutlist = [];
    $scope.summaryToggle = true;


    $ionicLoading.show({
        template: '<ion-spinner icon="ios"></ion-spinner>',
        duration: CONSTANT_TIMEOUT
    });

    $http.get(serviceUrl + "/node/" + workout_id, {timeout:CONSTANT_TIMEOUT}).then(function(response) {
        if (response.data.length != 0) {
            $scope.data.workoutlist.push(response.data);
        }
        $ionicLoading.hide();
    }, function(err) {
        ErrorHandler.errorHandler(err);
    });

    $scope.onHold = function(_nid, _index) {
        ErrorHandler.confirmPopup('Are you sure you want to delete this workout post?').then(function(res) {
            if (res == 1) {
                serviceWorkoutPost.remove({
                    id: _nid
                }).$promise.then(function(results) {
                    if (results[0]) {
                        $scope.data.workoutlist.splice(_index, 1);
                    }
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
        });
    }

    $scope.report = {};
    $scope.onHoldReport = function(_uid, _id, _type) {
        if (_uid != userId) {
            var options = {
                //addDestructiveButtonWithLabel: 'Block',
                buttonLabels: ['Report'],
                addCancelButtonWithLabel: 'Cancel',
                androidEnableCancelButton: true,
                winphoneEnableCancelButton: true
            };
            $cordovaActionSheet.show(options).then(function(btnIndex) {
                if (btnIndex == 1) report(_id, _type);
            })
        }
    }

    var report = function(_id, _type) {
        $ionicModal.fromTemplateUrl('templates/report_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.reportModal = modal;
            $scope.report.id = _id;
            $scope.report.type = _type;
            $scope.reportModal.show();
        });
    };

    $scope.closeReport = function() {
        $scope.reportModal.hide();
    }

    $scope.sendReport = function() {
        $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration:CONSTANT_TIMEOUT
        });
        var message = {};
        message['type'] = $scope.report.type
        message['tid'] = $scope.report.id;
        message['content'] = $scope.report.message;
        $http.post(serviceUrl + "/user/" + userId + "/report", message, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            $ionicLoading.hide();
            if (response.data) {
                NotificationHandler.success('Reported');
                $scope.reportModal.hide();
            }
        }, function(err) {
            $ionicLoading.hide();
            if (err.status == 406 && err.statusText.indexOf('You have already reported this content') > -1) $cordovaToast.showShortCenter(err.statusText);
            else ErrorHandler.errorHandler(err);
        });
    }

    //Recommend
    $scope.data.noMoreRecommendAvailable = true;
    $scope.recommendIndex = 0;
    var loadRecommend = function(_index, _workoutId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration:CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/node/" + _workoutId + "/load_recommends/" + _index, {},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreRecommendAvailable = true;
                else {
                    $scope.data.noMoreRecommendAvailable = false;
                    $scope.recommendIndex++;
                }
                var recommends = response.data;
                if (_flag) {
                    $scope.recommends = $scope.recommends.concat(recommends);
                } else $scope.recommends = recommends;
            } else {
                $scope.data.noMoreRecommendAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreRecommends = function(_nid) {
        loadRecommend($scope.recommendIndex, _nid, true);
    }

    $scope.openRecommendModal = function(_nid) {
        $ionicModal.fromTemplateUrl('modal_1.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_1 = modal;
            $scope.currentNID = _nid;
            loadRecommend($scope.recommendIndex, _nid, false);
            $scope.modal_1.show();
        });
    }

    $scope.openFullImageModal = function(_url) {
        $ionicModal.fromTemplateUrl('templates/full_image_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.fullImageModal = modal;
            $scope.fullImage = _url;
            if (window.StatusBar) {
                StatusBar.hide();
            }
            $scope.fullImageModal.show();
        });
    }

    $scope.closeFullImageModal = function() {
        //$ionicLoading.hide();
        $scope.fullImageModal.remove();
        if (window.StatusBar) {
            StatusBar.show();
        }
    }


    //Comment
    $scope.data.shouldShowCommentDelete = false;
    $scope.data.listCommentCanSwipe = true;

    $scope.data.noMoreCommentAvailable = true;

    $scope.commentIndex = 0;
    $scope.comments = [];
    var loadComment = function(_index, _nid, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration:CONSTANT_TIMEOUT
        });
        serviceComment.query({
            'parameters[nid]': _nid,
            page: _index,
            pagesize: 20
        }).$promise.then(function(results) {
            if (results.length != 0) {
                if (results.length < 20) $scope.data.noMoreCommentAvailable = true;
                else {
                    $scope.data.noMoreCommentAvailable = false;
                    $scope.commentIndex++;
                }
                var comments = results;
                if (_flag) {
                    $scope.comments = $scope.comments.concat(comments);
                } else $scope.comments = comments;
            } else {
                $scope.data.noMoreCommentAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreComments = function(_nid) {
        loadComment($scope.commentIndex, _nid, true);
    }

    $scope.openCommentModal = function(_workout, _flag, _index) { //_flag : true open the keyboard;
        $ionicModal.fromTemplateUrl('modal_2.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_2 = modal;
            $scope.currentNID = _workout.nid;
            $scope.currentIndex = _index;
            $scope.currentUID = _workout.uid;
            $scope.currentUsername = _workout.name;
            loadComment($scope.commentIndex, _workout.nid, false);
            $scope.modal_2.show();
        });
    }

    $scope.deleteComment = function(_index, _type) {
        var _cid = $scope.comments[_index].cid;
        serviceComment.remove({
            id: _cid
        }).$promise.then(function(results) {
            if (results[0]) {
                $scope.comments.splice(_index, 1);
                if (_type) { //fav
                    $scope.favouriteList[$scope.currentIndex].comment_count--;
                }
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.sendComment = function(_msg, _type) {
        var _comment = {
            "nid": $scope.currentNID,
            "name": userName,
            "comment_body": {
                "und": [{
                    "value": _msg
                }]
            }
        }
        serviceComment.post(_comment).$promise.then(function(results) {
            $scope.comments = $scope.comments.concat(results);
            if (_type) { //fav
                $scope.favouriteList[$scope.currentIndex].comment_count++;
                $scope.favouriteList[$scope.currentIndex].commented = true;
            } else {
                $scope.data.workoutlist[$scope.currentIndex].comment_count++;
                $scope.data.workoutlist[$scope.currentIndex].commented = true;
            }
            $scope.data.commentMessage = "";

            if (user.id != $scope.currentUID) {
                NotificationService.send(user.name, user.uid, $scope.currentUsername, $scope.currentUID, $scope.currentNID, 4);
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.closeModal = function(_id) {
        if (_id === 1) {
            $scope.modal_1.remove().then(function() {
                $scope.recommends = [];
                $scope.data.noMoreRecommendAvailable = true;
                $scope.recommendIndex = 0;
            });
        }
        if (_id === 2) {
            $scope.modal_2.remove().then(function() {
                $scope.comments = [];
                $scope.data.noMoreCommentAvailable = true;
                $scope.commentIndex = 0;
            });

        }
    }

    var favRecFunction = function(_nid, _action) {
        return $http.post(serviceUrl + '/node/' + _nid + '/' + _action, {timeout:CONSTANT_TIMEOUT})
    }

    $scope.favouriteClick = function(_nid, _status, _index, _type) {
        if (_status == 0) { //action, favourite
            favRecFunction(_nid, 'favourite').then(function(response) {
                if (response.status == 200) {
                    if (_type) $scope.favouriteList[_index].favourite = 1;
                    NotificationHandler.favToast(0);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unfavourite
            favRecFunction(_nid, 'unfavourite').then(function(response) {
                if (response.status == 200) {
                    if (_type) $scope.favouriteList[_index].favourite = 0;
                    NotificationHandler.favToast(1);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.recommendClick = function(_workout, _index, _type) {
        var _nid = _workout.nid;
        var _status = _workout.recommend;
        if (_status == 0) { //action, recommend
            favRecFunction(_nid, 'recommend').then(function(response) {
                if (response.status == 200) {
                    if (_type) {
                        $scope.favouriteList[_index].recommend = 1;
                        $scope.favouriteList[_index].recommends++;
                    } else {
                        $scope.data.workoutlist[_index].recommend = 1;
                        $scope.data.workoutlist[_index].recommends++;
                    }
                    if (user.uid != _workout.uid) {
                        NotificationService.send(user.name, user.uid, _workout.name, _workout.uid, _nid, 3);
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unrecommend
            favRecFunction(_nid, 'unrecommend').then(function(response) {
                if (response.status == 200) {
                    if (_type) {
                        $scope.favouriteList[_index].recommend = 0;
                        if ($scope.favouriteList[_index].recommends != 0) $scope.favouriteList[_index].recommends--;
                        else $scope.favouriteList[_index].recommends = 0;
                    } else {
                        $scope.data.workoutlist[_index].recommend = 0;
                        if ($scope.data.workoutlist[_index].recommends != 0) $scope.data.workoutlist[_index].recommends--;
                        else $scope.data.workoutlist[_index].recommends = 0;
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    var navTo = function(_uid) {
        if (_uid) {
            if (_uid == userId) {
                $state.go('tabs.myprofile')
            } else {
                $localStorage.fromfeed = "tabs.myprofile";
                $state.go('visitorprofile', {
                    target: _uid
                });
            }
        }
    }

    $scope.navToProfile = function(_uid, _type) {
        if (_type === 1) {
            $scope.modal_1.remove().then(function() {
                navTo(_uid);
            });
        }
        if (_type === 2) {
            $scope.modal_2.remove().then(function() {
                navTo(_uid);
            });
        } else {
            navTo(_uid);
        }
    };

    $scope.rowClass = function(exercise_index, set_index, subset_length) {
        return workoutStyle.rowClass(exercise_index, set_index, subset_length);
    };
    $scope.headClass = function(exercise_index, exercises_length) {
        return workoutStyle.headClassExercise(exercise_index, exercises_length);
    };

    $scope.rowClassFirst = function(exercise_index, set_index, workout_set) {
        return workoutStyle.rowClassFirst(exercise_index, set_index, workout_set);
    };

    $scope.widthFn = function(display_type, position) {
        return workoutStyle.widthFn(display_type, position);
    };

    $scope.tableStyle = function(_index, _length) {
        return workoutStyle.tableStyle(_index, _length);
    };
});

app.controller('DonationCtrl', function($scope) {

    var options = {
        location: 'yes',
        clearcache: 'no',
        toolbar: 'yes'
    };

    $scope.donate = function() {
        window.open('https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=D2CKNNDNE62TY', '_system', options);
    };

    /*
    $scope.donate = function() {
        $cordovaInAppBrowser.open(' https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=D2CKNNDNE62TY', '_blank', options)
            .then(function(event) {
                // success
            })
            .catch(function(event) {
                // error
            });
    };*/
    /*
    $scope.close = function() {
        $cordovaInAppBrowser.close();
    };*/
})

app.controller('GalleryCtrl', function($scope, $state, $http, ErrorHandler, $localStorage, $stateParams, Constants, $ionicModal, $ionicLoading, $ionicHistory, $ionicSlideBoxDelegate) {
    var uid = $stateParams.uid;
    var user = $localStorage.loginuser;
    var _uid = user.uid;
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    $scope.FullIMG = Constants.API.IMG_PATH;
    $scope.Thumbnail = Constants.API.Thumbnail;

    var galleryIndex = 0;
    $scope.noMoreImageAvailable = true;
    $scope.galleryImages = [];

    var loadImage = function(_index, _uid, _flag) {
        $http.post(serviceUrl + "/user/" + _uid + "/gallery/" + _index, {}, {timeout:CONSTANT_TIMEOUT}).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.noMoreImageAvailable = true;
                else {
                    $scope.noMoreImageAvailable = false;
                    galleryIndex++;
                }
                if (_flag) $scope.galleryImages = $scope.galleryImages.concat(response.data);
                else $scope.galleryImages = response.data
            } else {
                $scope.noMoreImageAvailable = true;
            }
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    loadImage(galleryIndex, uid, false);

    $scope.loadMoreImages = function() {
        loadImage(galleryIndex, uid, true);
    }

    $ionicModal.fromTemplateUrl('templates/gallery_image_modal.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function(modal) {
        $scope.modal = modal;
    });


    $scope.naviBackTo = function() {
        if (uid == _uid) {
            $state.go('tabs.myprofile', {
                reload: true
            });
        } else {
            $state.go('visitorprofile', {
                target: uid
            }, {
                reload: true
            });
        }
    };

    $scope.$on('$destroy', function() {
        $scope.modal.remove();
    })

    $scope.openImageModal = function(_index) {
        if (window.StatusBar) {
            // org.apache.cordova.statusbar required
            StatusBar.hide();
        }
        $ionicSlideBoxDelegate.slide(_index);
        $scope.modal.show();

    };

    $scope.closeImageModal = function() {
        $scope.modal.hide();
        if (window.StatusBar) {
            StatusBar.show();
        }

    };

    $scope.slideChanged = function(index) {
        $scope.slideIndex = index;
    };

});