'use strict'
angular.module('controllers.shareworkoutPost', ['ionic', 'ngCordova']).controller('ShareWorkoutCtrl', function($scope, $state, Constants, $ionicHistory, $rootScope, $http, $localStorage, $cordovaActionSheet, $cordovaCamera, $ionicLoading, $ionicNavBarDelegate, workoutService, $jrCrop, $cordovaDialogs, $cordovaProgress, $cordovaNetwork, ErrorHandler) {
    var user = $localStorage.loginuser;
    var CONSTANT_TIMEOUT=Constants.timeout;
    var userId = user.uid;
    var userName = user.name;
    $scope.workoutpost = {};
    $scope.workoutpost.shareToProfile = true;

    if (!$localStorage.workoutpost) $localStorage.workoutpost = [];
    var baseUrl = Constants.API.baseUrl;
    var serviceUrl = Constants.API.serviceUrl;
    var token_url = Constants.API.tokenUrl;
    var photoChoosePopup;
    var imageData;

    if ($localStorage.teams) {
        $scope.teams = $localStorage.teams
    } else {
        $http.post(serviceUrl + "/user/" + userId + "/team",{},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
            $scope.teams = response.data;
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }
    $scope.pickPhoto = function() {
            var options = {
                title: 'Choose photo from..',
                buttonLabels: ['Camera', 'Photo Library'],
                addCancelButtonWithLabel: 'Cancel',
                androidEnableCancelButton: true,
                winphoneEnableCancelButton: true
            };
            $cordovaActionSheet.show(options)
                .then(function(btnIndex) {
                    var index = btnIndex;
                    if (btnIndex == 1) takePhoto();
                    if (btnIndex == 2) choosePhoto();
                });
        }
        /*
        $scope.tagFriend = function() {
            photoChoosePopup = $ionicPopup.show({
                template: '',
                title: 'Friend List',
                scope: $scope,
                buttons: [{
                    text: 'Cancel',
                    type: 'button-light'
                }]
            });
        }*/
    var choosePhoto = function() {
        var options = {
            quality: 30,
            destinationType: Camera.DestinationType.DATA_URL,
            //sourceType : Camera.PictureSourceType.CAMERA, 
            sourceType: Camera.PictureSourceType.PHOTOLIBRARY,
            allowEdit: false,
            encodingType: Camera.EncodingType.JPEG,
            //targetWidth: 480,
            //targetHeight: 270,
            mediaType: 0, //set to photo only
            correctOrientation: true,
            //popoverOptions: CameraPopoverOptions,
            saveToPhotoAlbum: false
        };

        $cordovaCamera.getPicture(options).then(function(_imageData) {
            $jrCrop.crop({
                url: "data:image/jpeg;base64," + _imageData,
                width: window.innerWidth,
                aspectRatio: 16 / 9,
                scale: 1
            }).then(function(canvas) {
                var _dataURL = canvas.toDataURL();
                $scope.workoutpost.imgURI = _dataURL;
                imageData = _dataURL.split(',')[1];
            }, function(err) {
                console.log(err);
            });
        }, function(err) {
            console.log(err);
        });
    }

    var takePhoto = function() {
        var options = {
            quality: 30,
            destinationType: Camera.DestinationType.DATA_URL,
            sourceType: Camera.PictureSourceType.CAMERA,
            //sourceType : Camera.PictureSourceType.PHOTOLIBRARY,
            allowEdit: false,
            encodingType: Camera.EncodingType.JPEG,
            //targetWidth: 480,
            //targetHeight: 270,
            correctOrientation: true,
            //popoverOptions: CameraPopoverOptions,
            saveToPhotoAlbum: false
        };
        $cordovaCamera.getPicture(options).then(function(_imageData) {
            $jrCrop.crop({
                url: "data:image/jpeg;base64," + _imageData,
                width: window.innerWidth,
                aspectRatio: 16 / 9,
                scale: 1
            }).then(function(canvas) {
                var _dataURL = canvas.toDataURL();
                $scope.workoutpost.imgURI = _dataURL;
                imageData = _dataURL.split(',')[1];;
            }, function(err) {
                console.log(err);
            });
        }, function(err) {
            console.log(err);
        });
    }

    $scope.backToPrevious = function() {
        if (!$ionicHistory.viewHistory().backView) {
            $state.go('tabs.postworkout');
        } else {
            $ionicHistory.goBack();
        }
    }

    var shareToTeam = function(_nid, _teamId) {
        $http.get(Constants.API.serviceUrl + "/node/" + _nid,{timeout:CONSTANT_TIMEOUT}).then(function(response) {
            var workoutpost = response.data;
            io.socket.post('/chat/room/' + _teamId, {
                uid: userId,
                team: _teamId,
                user: userName,
                messageType: 'workout',
                message: JSON.stringify(workoutpost)
            });
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.postWorkoutFn = function() {
        var selectedTeams = [];
        angular.forEach($scope.teams, function(team) {
            if (team.checked) {
                this.push(team.gid);
            }
        }, selectedTeams);

        if (selectedTeams.length == 0 && !$scope.workoutpost.shareToProfile) {
            ErrorHandler.alertPopup('Please select at least one place to share your workout!');
        } else {
            $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner> <p>Posting...</p>',
                duration:CONSTANT_TIMEOUT
            });
            var workoutpost = {};
            workoutpost["type"] = "workout";
            var timestamp = new Date().getTime();
            workoutpost["title_field"] = "Workoutpost_" + userId + "_" + timestamp;
            workoutpost["field_statement"] = $scope.workoutpost.statement || "";
            workoutpost["field_share_to_profile"] = $scope.workoutpost.shareToProfile || 0;
            workoutpost["uid"] = userId;
            var _workoutpost = {};
            _workoutpost["uid"] = userId;
            var _unit = workoutService.getUnit();
            _workoutpost["weightUnit"] = _unit.weightUnit;
            _workoutpost["distanceUnit"] = _unit.distanceUnit;
            var _workouts = workoutService.getWorkoutPost();
            _workoutpost['workouts'] = _workouts;
            var _postData = {};
            _postData['workoutpost'] = _workoutpost;
            _postData['selectedteams'] = selectedTeams;


            _postData['workoutnode'] = workoutpost;

            if ($cordovaNetwork.isOnline()) {
                if ($scope.workoutpost.imgURI) //if image, upload the image
                {
                    var imagePost = {};
                    imagePost['uid'] = userId;
                    imagePost['file'] = imageData;
                    imagePost['filesize'] = imageData.length;
                    imagePost['filename'] = "workout_" + userId + "_" + timestamp + ".jpg";
                    $http.post(baseUrl + '/rest/api/file', imagePost,{timeout:CONSTANT_TIMEOUT}).success(function(data, status, headers, config) {
                        workoutpost["field_image"] = data.fid;
                        _postData['workoutnode'] = workoutpost;
                        $http.post(baseUrl + '/rest/api/workoutpost', _postData, {timeout:CONSTANT_TIMEOUT}).
                        success(function(data, status, headers, config) {
                            var _nid = data.nid;
                            if (selectedTeams.length != 0) {
                                angular.forEach(selectedTeams, function(team) {
                                    shareToTeam(_nid, team);
                                });
                            }
                            $ionicLoading.hide();
                            //$ionicHistory.clearCache();
                            if ($scope.workoutpost.shareToProfile) {
                                workoutService.initial();
                                delete $localStorage.workoutlist;
                                $state.go("tabs.livefeed");
                            } else {
                                workoutService.initial();
                                $state.go("tabs.teams");
                            }
                        }).error(function(err) {
                            ErrorHandler.errorHandler(err);
                        });
                    }).error(function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                } else {
                    _postData['workoutnode'] = workoutpost;
                    $http.post(baseUrl + '/rest/api/workoutpost', _postData,{timeout:CONSTANT_TIMEOUT}).
                    success(function(data, status, headers, config) {
                        var _nid = data.nid;
                        if (selectedTeams.length != 0) {
                            angular.forEach(selectedTeams, function(team) {
                                shareToTeam(_nid, team);
                            });
                        }
                        $ionicLoading.hide();
                        if ($scope.workoutpost.shareToProfile) {
                            workoutService.initial();
                            delete $localStorage.workoutlist;
                            $state.go("tabs.livefeed");
                        } else {
                            workoutService.initial();
                            $state.go("tabs.teams");
                        }
                    }).error(function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }
            } else {
                $ionicLoading.hide();
                var offline_workout = {};
                if ($scope.workoutpost.imgURI) //if image
                {
                    var imagePost = {};
                    imagePost['uid'] = userId;
                    imagePost['file'] = imageData;
                    imagePost['filesize'] = imageData.length;
                    imagePost['filename'] = "workout_" + userId + "_" + timestamp + ".jpg";
                    imagePost['type'] = 1;
                    offline_workout['imagePost'] = imagePost;
                }
                offline_workout['_postData'] = angular.copy(_postData);
                offline_workout['workoutpost'] = angular.copy(workoutpost);
                $localStorage.offline_workout = offline_workout;
                workoutService.initial();
                $state.go("tabs.livefeed");
            }
        }
    }

});