'use.strict'

angular.module('controllers.livefeed', ['ionic', 'ngResource']).controller('LiveFeedCtrl', function($scope, $state, $http, NotificationService, $cordovaNetwork, $stateParams, workoutStyle, ErrorHandler, $ionicLoading, NotificationHandler, $localStorage, $stateParams, $cordovaActionSheet, Constants, $ionicModal, $timeout, $q, serviceUser, $cordovaProgress, $cordovaToast, workoutService, serviceComment) {
    var serviceUrl = Constants.API.serviceUrl;
    var baseUrl = Constants.API.baseUrl;
    var IMG_PATH = Constants.API.IMG_PATH;
    var Thumbnail = Constants.API.Thumbnail;
    var Profile_Thumbnail = Constants.API.Profile_Thumbnail;

    var CONSTANT_TIMEOUT = Constants.timeout;
    var user = $localStorage.loginuser;
    var userId = user.uid;
    var userName = user.name;

    $scope.userId = user.uid;
    $scope.userPrivacy = user.privacy;
    $scope.dailyMotivation = false; // inital make up data
    $scope.summaryToggle = true;
    $scope.weightUnit = user.weightUnit;
    $scope.distanceUnit = user.distanceUnit;


    $scope.data = {};
    $scope.data.noMoreRecommendAvailable = true;
    $scope.data.noMoreCommentAvailable = true;
    $scope.noMoreItemsAvailable = true;
    $scope.recommendIndex = 0;
    $scope.commentIndex = 0;

    if ($localStorage.offline_workout) {
        $scope.data.offline_workout = true;
    }

    //TODO:post to sever
    $scope.dailyMotivationClose = function() {
        $scope.dailyMotivation = false;
    }

    var shareToTeam = function(_nid, _teamId) {
        $http.get(serviceUrl + "/node/" + _nid, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            var workoutpost = response.data;
            io.socket.post('/chat/room/' + _teamId, {
                uid: userId,
                team: _teamId,
                user: userName,
                messageType: 'workout',
                message: JSON.stringify(workoutpost)
            });
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }


    var doRefreshPromise = function(_pageIndex) {
        return $http.post(serviceUrl + '/user/' + userId + '/livefeed/' + _pageIndex, {}, {
            timeout: CONSTANT_TIMEOUT
        });
    }
    var loadPosts = function(_index) {
        return doRefreshPromise(_index).then(function(_results) {
            var results = _results.data;
            if ($scope.weightUnit != "kg" || $scope.distanceUnit != "m/km") {
                var _weightExchangeRate = 1;
                if ($scope.weightUnit == "lb") _weightExchangeRate = 0.45359;
                else if ($scope.weightUnit == "st") _weightExchangeRate = 6.35029;
                var _distanceExachangeRate = 1;
                if ($scope.distanceUnit == "mile") _distanceExachangeRate = 1.6;
                angular.forEach(results, function(result) {
                    var summaries = result.summary;
                    angular.forEach(summaries, function(e) {
                        if (e.weight != -1) {
                            var _t = e.weight / _weightExchangeRate;
                            e.weight = _t.toFixed(2);
                        }
                        if (e.distance != -1) {
                            var _t = e.distance / _distanceExachangeRate;
                            e.distance = _t.toFixed(2);
                        }
                    });
                });
            }
            if (results.length < 8) $scope.noMoreItemsAvailable = true;
            else {
                $scope.noMoreItemsAvailable = false;
                $localStorage.workoutIndex++;
            }
            $localStorage.noMoreItemsAvailable = $scope.noMoreItemsAvailable;
            return results;
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.doRefresh = function() {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            duration: CONSTANT_TIMEOUT
        });
        $localStorage.workoutIndex = 0;
        loadPosts(0).then(function(workoutlist) {
            $scope.workoutlist = workoutlist;
            $localStorage.workoutlist = workoutlist;
            $scope.lastUpdate = (new Date()).getTime() / 1000;
            $ionicLoading.hide();
            $scope.$broadcast('scroll.refreshComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    if (!$localStorage.workoutIndex || !$localStorage.workoutlist || ($stateParams.refreshFlag && $stateParams.refreshFlag == 1)) {
        $scope.doRefresh();
    } else {
        $scope.workoutlist = $localStorage.workoutlist;
        if (!$localStorage.workoutIndex) $localStorage.workoutIndex = Math.floor($scope.workoutlist.length / 8) - 1;
    }

    $scope.report = {};
    $scope.onHoldReport = function(_uid, _id, _type) {
        if (_uid != userId) {
            var options = {
                //addDestructiveButtonWithLabel: 'Block',
                buttonLabels: ['Report'],
                addCancelButtonWithLabel: 'Cancel',
                androidEnableCancelButton: true,
                winphoneEnableCancelButton: true
            };
            $cordovaActionSheet.show(options).then(function(btnIndex) {
                if (btnIndex == 1) report(_id, _type);
            })
        }
    }

    var report = function(_id, _type) {
        $ionicModal.fromTemplateUrl('templates/report_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.reportModal = modal;
            $scope.report.id = _id;
            $scope.report.type = _type;
            $scope.reportModal.show();
        });
    };

    $scope.closeReport = function() {
        $scope.reportModal.hide();
    }
    $scope.sendReport = function() {
        $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration:CONSTANT_TIMEOUT
        });
        var message = {};
        message['type'] = $scope.report.type
        message['tid'] = $scope.report.id;
        message['content'] = $scope.report.message;
        $http.post(serviceUrl + "/user/" + userId + "/report", message, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            $ionicLoading.hide();
            if (response.data) {
                NotificationHandler.success('Reported');
                $scope.reportModal.hide();
            }
        }, function(err) {
            $ionicLoading.hide();
            if (err.status == 406 && err.statusText.indexOf('You have already reported this content') > -1) $cordovaToast.showShortCenter(err.statusText);
            else ErrorHandler.errorHandler(err);
        });
    }

    $scope.rePostOffline = function() {
        if (!$cordovaNetwork.isOnline()) {
            ErrorHandler.alertPopup('Network offline');
        } else {
            NotificationHandler.confirmRepost("Do you want to resend the post or delete?", "Confirm").then(function(btnIndex) {
                if (btnIndex == 2) { //confirm resend
                    $ionicLoading.show({
                        template: '<ion-spinner icon="ios"></ion-spinner> <p>Posting...</p>',
                        duration: CONSTANT_TIMEOUT
                    });
                    var _offline_workout = $localStorage.offline_workout;
                    if (_offline_workout.imagePost) {
                        var imagePost = _offline_workout.imagePost;
                        var _postData = _offline_workout._postData;
                        var workoutpost = _offline_workout.workoutpost;
                        var selectedTeams = _postData.selectedteams;

                        $http.post(baseUrl + '/rest/api/file', imagePost, {
                            timeout: CONSTANT_TIMEOUT
                        }).
                        success(function(data, status, headers, config) {
                            workoutpost["field_image"] = data.fid;
                            _postData['workoutnode'] = workoutpost;
                            $http.post(baseUrl + '/rest/api/workoutpost', _postData, {
                                timeout: CONSTANT_TIMEOUT
                            }).
                            success(function(data, status, headers, config) {
                                var _nid = data.nid;
                                if (selectedTeams.length != 0) {
                                    angular.forEach(selectedTeams, function(team) {
                                        shareToTeam(_nid, team);
                                    });
                                }
                                $ionicLoading.hide();
                                $scope.data.offline_workout = false;
                                if (workoutpost.field_share_to_profile) {
                                    delete $localStorage.offline_workout;
                                    $scope.doRefresh();
                                } else {
                                    delete $localStorage.offline_workout;
                                    $state.go("tabs.teams");
                                }
                            }).error(function(err) {
                                ErrorHandler.errorHandler(err);
                            });
                        }).error(function(err) {
                            ErrorHandler.errorHandler(err);
                        });
                    } else {
                        var _postData = _offline_workout._postData;
                        var workoutpost = _offline_workout.workoutpost;
                        var selectedTeams = _postData.selectedteams;
                        _postData['workoutnode'] = _offline_workout.workoutpost;
                        $http.post(baseUrl + '/rest/api/workoutpost', _postData, {
                            timeout: CONSTANT_TIMEOUT
                        }).
                        success(function(data, status, headers, config) {
                            var _nid = data.nid;
                            if (selectedTeams.length != 0) {
                                angular.forEach(selectedTeams, function(team) {
                                    shareToTeam(_nid, team);
                                });
                            }
                            $ionicLoading.hide();
                            $scope.data.offline_workout = false;
                            if (workoutpost.field_share_to_profile) {
                                delete $localStorage.offline_workout;
                                $scope.doRefresh();
                            } else {
                                delete $localStorage.offline_workout;
                                $state.go("tabs.teams");
                            }
                        }).error(function(err) {
                            ErrorHandler.errorHandler(err);
                        });
                    }
                } else if (btnIndex == 1) {
                    $scope.data.offline_workout = false;
                    delete $localStorage.offline_workout;
                }
            });
        }
    }

    $scope.loadMore = function() {
        loadPosts($localStorage.workoutIndex).then(function(workoutlist) {
            $scope.workoutlist = $scope.workoutlist.concat(workoutlist);
            $localStorage.workoutlist = $scope.workoutlist;
            $scope.$broadcast('scroll.infiniteScrollComplete');
        });
    }

    $scope.openFullImageModal = function(_url) {
        $ionicModal.fromTemplateUrl('templates/full_image_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.fullImageModal = modal;
            $scope.fullImage = _url;
            if (window.StatusBar) {
                StatusBar.hide();
            }
            $scope.fullImageModal.show();
        });
    }

    $scope.closeFullImageModal = function() {
        //$ionicLoading.hide();
        $scope.fullImageModal.remove();
        if (window.StatusBar) {
            StatusBar.show();
        }
    }
    $scope.recommends = [];
    var loadRecommend = function(_index, _workoutId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration: CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/node/" + _workoutId + "/load_recommends/" + _index, {}, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreRecommendAvailable = true;
                else {
                    $scope.data.noMoreRecommendAvailable = false;
                    $scope.recommendIndex++;
                }
                var recommends = response.data;
                if (_flag) {
                    $scope.recommends = $scope.recommends.concat(recommends);
                } else $scope.recommends = recommends;
            } else {
                $scope.data.noMoreRecommendAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreRecommends = function(_nid) {
        loadRecommend($scope.recommendIndex, _nid, true);
    }

    $scope.openRecommendModal = function(_nid) {
        $ionicModal.fromTemplateUrl('modal_1.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_1 = modal;
            $scope.currentNID = _nid;
            loadRecommend($scope.recommendIndex, _nid, false);
            $scope.modal_1.show();
        });
    }

    $scope.comments = [];
    var loadComment = function(_index, _nid, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration: CONSTANT_TIMEOUT
        });
        serviceComment.query({
            'parameters[nid]': _nid,
            page: _index,
            pagesize: 20
        }).$promise.then(function(results) {
            if (results.length != 0) {
                if (results.length < 20) $scope.data.noMoreCommentAvailable = true;
                else {
                    $scope.data.noMoreCommentAvailable = false;
                    $scope.commentIndex++;
                }
                var comments = results;
                if (_flag) {
                    $scope.comments = $scope.comments.concat(comments);
                } else $scope.comments = comments;
            } else {
                $scope.data.noMoreCommentAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreComments = function(_nid) {
        loadComment($scope.commentIndex, _nid, true);
    }

    $scope.openCommentModal = function(_workout, _flag, _index) { //_flag : true open the keyboard;
        $ionicModal.fromTemplateUrl('modal_2.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_2 = modal;
            $scope.currentNID = _workout.nid;
            $scope.currentIndex = _index;
            $scope.currentUID = _workout.uid;
            $scope.currentUsername = _workout.name;
            loadComment($scope.commentIndex, _workout.nid, false);
            $scope.modal_2.show();
        });
    }

    $scope.sendComment = function(_msg) {
        var _comment = {
            "nid": $scope.currentNID,
            "name": userName,
            "comment_body": {
                "und": [{
                    "value": _msg
                }]
            }
        }

        serviceComment.post(_comment).$promise.then(function(results) {
            $scope.comments = $scope.comments.concat(results);
            $scope.workoutlist[$scope.currentIndex].comment_count++;
            $scope.workoutlist[$scope.currentIndex].commented = true;
            $scope.data.commentMessage = "";
            if (user.id != $scope.currentUID) {
                NotificationService.send(user.name, user.uid, $scope.currentUsername, $scope.currentUID, $scope.currentNID, 4);
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.data.shouldShowCommentDelete = false;
    $scope.data.listCommentCanSwipe = true;
    $scope.deleteComment = function(_index, _type) {
        var _cid = $scope.comments[_index].cid;
        serviceComment.remove({
            id: _cid
        }).$promise.then(function(results) {
            if (results[0]) {
                $scope.comments.splice(_index, 1);
                if (_type) { //fav
                    $scope.favouriteList[$scope.currentIndex].comment_count--;
                } else {
                    $scope.workoutlist[$scope.currentIndex].comment_count--;
                }
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.closeModal = function(_id) {
        if (_id === 1) {
            $scope.modal_1.remove().then(function() {
                $scope.recommends = [];
                $scope.data.noMoreRecommendAvailable = true;
                $scope.recommendIndex = 0;
            });
        }
        if (_id === 2) {
            $scope.modal_2.remove().then(function() {
                $scope.comments = [];
                $scope.data.noMoreCommentAvailable = true;
                $scope.commentIndex = 0;
            });
        }
    }

    var favRecFunction = function(_nid, _action) {
        return $http.post(serviceUrl + '/node/' + _nid + '/' + _action, {}, {
            timeout: CONSTANT_TIMEOUT
        })
    }

    $scope.favouriteClick = function(_nid, _status, _index) {
        if (_status == 0) { //action, favourite
            favRecFunction(_nid, 'favourite').then(function(response) {
                if (response.status == 200) {
                    $scope.workoutlist[_index].favourite = 1;
                    NotificationHandler.favToast(0);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unfavourite
            favRecFunction(_nid, 'unfavourite').then(function(response) {
                if (response.status == 200) {
                    $scope.workoutlist[_index].favourite = 0;
                    NotificationHandler.favToast(1);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.recommendClick = function(_workout, _index) {
        var _nid = _workout.nid;
        var _status = _workout.recommend;
        if (_status == 0) { //action, recommend
            favRecFunction(_nid, 'recommend').then(function(response) {
                if (response.status == 200) {
                    $scope.workoutlist[_index].recommend = 1;
                    $scope.workoutlist[_index].recommends++;
                    if (user.uid != _workout.uid) {
                        NotificationService.send(user.name, user.uid, _workout.name, _workout.uid, _nid, 3);
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unrecommend
            favRecFunction(_nid, 'unrecommend').then(function(response) {
                if (response.status == 200) {
                    $scope.workoutlist[_index].recommend = 0;
                    if ($scope.workoutlist[_index].recommends != 0) $scope.workoutlist[_index].recommends--;
                    else $scope.workoutlist[_index].recommends = 0;
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.navTo = function(_uid) {
        if (_uid) {
            if (_uid == userId) {
                $state.go('tabs.myprofile')
            } else {
                $state.go('visitorprofile', {
                    target: _uid
                });
            }
        }
    }

    $scope.navToProfile = function(_uid, _type) {
        if (_type === 1) {
            $scope.modal_1.remove().then(function() {
                $scope.recommends = [];
                $scope.data.noMoreRecommendAvailable = true;
                $scope.recommendIndex = 0;
                if (_uid) {
                    if (_uid == userId) {
                        $state.go('tabs.myprofile')
                    } else {
                        $state.go('visitorprofile', {
                            target: _uid
                        });
                    }
                }
            });
        }
        if (_type === 2) {
            $scope.modal_2.remove().then(function() {
                $scope.comments = [];
                $scope.data.noMoreCommentAvailable = true;
                $scope.commentIndex = 0;
                if (_uid) {
                    if (_uid == userId) {
                        $state.go('tabs.myprofile')
                    } else {
                        $state.go('visitorprofile', {
                            target: _uid
                        });
                    }
                }
            });
        }
    }

    $scope.rowClass = function(exercise_index, set_index, subset_length) {
        return workoutStyle.rowClass(exercise_index, set_index, subset_length);
    };
    /*
    $scope.headClass = function(exercise_index) {
        return workoutStyle.headClass(exercise_index);
    };*/

    $scope.headClass = function(exercise_index, exercises_length) {
        return workoutStyle.headClassExercise(exercise_index, exercises_length);
    };

    $scope.rowClassFirst = function(exercise_index, set_index, workout_set) {
        return workoutStyle.rowClassFirst(exercise_index, set_index, workout_set);
    };

    $scope.widthFn = function(display_type, position) {
        return workoutStyle.widthFn(display_type, position);
    };

    $scope.tableStyle = function(_index, _length) {
        return workoutStyle.tableStyle(_index, _length);
    };
});