'use.strict'

var app = angular.module('controllers.profile', ['ionic', 'ngResource']);
app.controller('ProfileCtrl', function($scope, $http, $ionicHistory, NotificationService, $localStorage, NotificationHandler, $ionicLoading, $ionicPopup, ErrorHandler, $state, serviceFile, $timeout, serviceUser, UserDataService, ErrorHandler, $cordovaActionSheet, $cordovaToast, Constants, $cordovaProgress, $ionicModal, workoutService, workoutStyle, serviceComment, serviceWorkoutPost, ImageService, $jrCrop) {
    var countryList = Constants.countryList;
    $scope.countries = countryList;
    var baseUrl = Constants.API.baseUrl;
    var IMG_PATH = Constants.API.IMG_PATH;
    var Profile_Thumbnail = Constants.API.Profile_Thumbnail;
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT = Constants.timeout;

    $scope.selectedCountry = $scope.countries[countryList.indexOf('United Kingdom')];
    var user = $localStorage.loginuser;
    var userId = user.uid;
    var userName = user.name;

    $scope.userId = userId;
    workoutService.setUnit(user.weightUnit, user.distanceUnit);
    $scope.user = user;
    $scope.user.tempBio = user.bio;
    $scope.data = {};
    $scope.data.type = true;
    $scope.weightUnit = user.weightUnit;
    $scope.distanceUnit = user.distanceUnit;

    $scope.doRefresh = function() {
        serviceUser.get({
            id: userId
        }).$promise.then(function(_user) {
            var _displayUser = UserDataService.displayUser(_user);
            workoutService.setUnit(_displayUser.weightUnit, _displayUser.distanceUnit);
            $scope.user = _displayUser;
            $scope.user.tempBio = _displayUser.bio;
            $localStorage.loginuser = _displayUser;
            $scope.$broadcast('scroll.refreshComplete');
        }, function(err) {
            ErrorHandler.errorHandler(error);
        });
    }

    $scope.doRefresh();


    $scope.pickPhoto = function() {
        ImageService.pickPhoto().then(function(btnIndex) {
            if (btnIndex == 1) {
                ImageService.takePhoto().then(function(_imageData) {
                    $jrCrop.crop({
                        url: "data:image/jpeg;base64," + _imageData,
                        width: window.innerWidth,
                        aspectRatio: 16 / 9,
                        scale: 1
                    }).then(function(canvas) {
                        var _dataURL = canvas.toDataURL();
                        $scope.user.picturePath = _dataURL;
                        ImageService.postProfileImage(_dataURL.split(',')[1], userId);
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
            if (btnIndex == 2) {
                ImageService.choosePhoto().then(function(_imageData) {
                    $jrCrop.crop({
                        url: "data:image/jpeg;base64," + _imageData,
                        width: window.innerWidth,
                        aspectRatio: 16 / 9,
                        scale: 1
                    }).then(function(canvas) {
                        if (canvas != null) {
                            var _dataURL = canvas.toDataURL();
                            $scope.user.picturePath = _dataURL;
                            ImageService.postProfileImage(_dataURL.split(',')[1], userId);
                        } else {
                            $cordovaToast.showShortCenter("Current Image is not supproted!");
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
        });
    }


    $scope.saveBio = function() {
        var _obj = {};
        _obj['value'] = $scope.user.tempBio;
        var _bio = {};
        _bio["field_bio"] = {
            'und': {
                '0': _obj
            }
        };
        serviceUser.update({
            id: userId
        }, _bio).$promise.then(function(user) {
            $scope.user.bio = $scope.user.tempBio;
            $scope.closeBioModal();
            $cordovaProgress.showSuccess(true, "Success!");
            $timeout(function() {
                $cordovaProgress.hide();
            }, 1000);
            var _user = $localStorage.loginuser;
            _user["field_bio"] = user["field_bio"];
            $localStorage.loginuser = _user;
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.openModal = function() {
        $ionicModal.fromTemplateUrl('bio_changemodal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.biomodal = modal;
            $scope.biomodal.show();
        });
    };




    $scope.closeBioModal = function() {
        $scope.biomodal.hide();
    };

    $scope.getFollowings = function(_uid) {
        /*$state.go('following', {
            uid: _uid
        }, {
            reload: true
        });*/
        $state.go('myfollowing', {
            reload: true
        });
    }

    $scope.getFollowers = function(_uid) {
        /*$state.go('followers', {
            uid: _uid
        }, {
            reload: true
        });*/
        $state.go('myfollowers', {
            reload: true
        });
    }

    $scope.navigateToGallery = function() {
        $state.go('gallery', {
            uid: userId
        });
    }

    $scope.report = {};
    $scope.onHoldReport = function(_uid, _id, _type) {
        if (_uid != userId) {
            var options = {
                //addDestructiveButtonWithLabel: 'Block',
                buttonLabels: ['Report'],
                addCancelButtonWithLabel: 'Cancel',
                androidEnableCancelButton: true,
                winphoneEnableCancelButton: true
            };
            $cordovaActionSheet.show(options).then(function(btnIndex) {
                if (btnIndex == 1) report(_id, _type);
            })
        }
    }

    var report = function(_id, _type) {
        $ionicModal.fromTemplateUrl('templates/report_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.reportModal = modal;
            $scope.report.id = _id;
            $scope.report.type = _type;
            $scope.reportModal.show();
        });
    };

    $scope.closeReport = function() {
        $scope.reportModal.hide();
    }
    $scope.sendReport = function() {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            duration: CONSTANT_TIMEOUT
        });
        var message = {};
        message['type'] = $scope.report.type
        message['tid'] = $scope.report.id;
        message['content'] = $scope.report.message;
        $http.post(serviceUrl + "/user/" + userId + "/report", message, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            $ionicLoading.hide();
            if (response.data) {
                NotificationHandler.success('Reported');
                $scope.reportModal.hide();
            }
        }, function(err) {
            $ionicLoading.hide();
            if (err.status == 406 && err.statusText.indexOf('You have already reported this content') > -1) $cordovaToast.showShortCenter(err.statusText);
            else ErrorHandler.errorHandler(err);
        });
    }



    $scope.onHold = function(_nid, _index) {
        ErrorHandler.confirmPopup('Are you sure you want to delete this workout post?').then(function(res) {
            if (res == 1) {
                serviceWorkoutPost.remove({
                    id: _nid
                }).$promise.then(function(results) {
                    if (results[0]) {
                        $scope.data.workoutlist.splice(_index, 1);
                    }
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
        });
    }

    $scope.infoEdit = function(_index) {
        var _msg = "Please enter your";
        var _title = "Edit";
        var _text = "";
        var _field = "";

        if (_index == 0) {
            _msg = _msg + " weight";
            _text = $scope.user.weight + ""; //ios need to be string for dialogs prompt
            _field = 'field_weight';
        } else if (_index == 1) {
            _msg = _msg + " body fat (%)";
            _text = $scope.user.bodyfat;
            _field = 'field_body_fat';
        } else if (_index == 2) {
            _msg = _msg + " height";
            _text = $scope.user.height + "";
            _field = 'field_height';
        } else if (_index == 3) {
            _msg = _msg + " rest bpm";
            _text = $scope.user.restbpm;
            _field = 'field_restbpm';
        }

        NotificationHandler.prompt(_msg, _title, _text).then(function(result) {
            var input = result.input1;
            var btnIndex = result.buttonIndex;
            if (btnIndex == 2) {
                if (!input || input == _text || isNaN(input) || input < 0) {
                    var errorMsg = 'Invalid Number';
                    if (input == _text) {
                        errorMsg = 'Same value';
                    }
                    NotificationHandler.alert(errorMsg);
                } else {
                    $ionicLoading.show({
                        template: '<ion-spinner icon="ios"></ion-spinner>',
                        duration: CONSTANT_TIMEOUT
                    });
                    var _obj = {};
                    _obj['value'] = input;
                    var _data = {};
                    _data[_field] = {
                        'und': {
                            '0': _obj
                        }
                    };
                    serviceUser.update({
                        id: userId
                    }, _data).$promise.then(function(user) {
                        $ionicLoading.hide();
                        $cordovaProgress.showSuccess(true, "Success!");
                        $timeout(function() {
                            $cordovaProgress.hide();
                        }, 1000);
                        $scope.doRefresh();
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }
            }
        });
    }

    //workout
    var workoutIndex = 0;
    $scope.data = {};
    $scope.data.noMoreWorkoutAvailable = true;
    $scope.data.workoutlist = [];
    $scope.summaryToggle = true;
    var loadWorkout = function(_index, _userId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            duration: CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/user/" + _userId + "/workout/" + _index, {}, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreWorkoutAvailable = true;
                else {
                    $scope.data.noMoreWorkoutAvailable = false;
                    workoutIndex++;
                }
                var workouts = response.data;
                if (_flag) {
                    $scope.data.workoutlist = $scope.data.workoutlist.concat(workouts);
                } else $scope.data.workoutlist = workouts;
            } else {
                $scope.data.noMoreWorkoutAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreWorkout = function() {
        loadWorkout(workoutIndex, userId, true);
    }

    $scope.showWorkouts = function() {
        $ionicModal.fromTemplateUrl('templates/profile_workout_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.workoutmodal = modal;
            loadWorkout(workoutIndex, userId, false);
            $scope.data.type = false;
            $scope.workoutmodal.show();
        });
    }
    $scope.closeWorkouts = function() {
        $scope.workoutmodal.remove();
    }

    //Favourites
    var favouriteIndex = 0;
    $scope.data.noMoreFavouriteAvailable = true;
    $scope.favouriteList = [];
    $scope.favSummaryToggle = true;
    var loadFavourite = function(_index, _userId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration: CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/user/" + _userId + "/favourite/" + _index, {}, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreFavouriteAvailable = true;
                else {
                    $scope.data.noMoreFavouriteAvailable = false;
                    favouriteIndex++;
                }
                var favourites = response.data;
                if (_flag) {
                    $scope.favouriteList = $scope.favouriteList.concat(favourites);
                } else $scope.favouriteList = favourites;
            } else {
                $scope.data.noMoreFavouriteAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreFavourite = function() {
        loadFavourite(favouriteIndex, userId, true);
    }

    $scope.showFavorites = function() {
        $ionicModal.fromTemplateUrl('templates/favourite_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.favouritemodal = modal;
            loadFavourite(favouriteIndex, userId, false);
            $scope.data.type = true;
            $scope.favouritemodal.show();
        });
    }

    $scope.closeFavorites = function() {
        $scope.favouritemodal.remove().then(function() {
            $scope.favouriteList = [];
            favouriteIndex = 0;
            $scope.data.noMoreFavouriteAvailable = true;
        });
    }

    //Recommend
    $scope.data.noMoreRecommendAvailable = true;
    $scope.recommendIndex = 0;
    var loadRecommend = function(_index, _workoutId, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration: CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/node/" + _workoutId + "/load_recommends/" + _index, {}, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.data.noMoreRecommendAvailable = true;
                else {
                    $scope.data.noMoreRecommendAvailable = false;
                    $scope.recommendIndex++;
                }
                var recommends = response.data;
                if (_flag) {
                    $scope.recommends = $scope.recommends.concat(recommends);
                } else $scope.recommends = recommends;
            } else {
                $scope.data.noMoreRecommendAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreRecommends = function(_nid) {
        loadRecommend($scope.recommendIndex, _nid, true);
    }

    $scope.openRecommendModal = function(_nid) {
        $ionicModal.fromTemplateUrl('modal_1.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_1 = modal;
            $scope.currentNID = _nid;
            loadRecommend($scope.recommendIndex, _nid, false);
            $scope.modal_1.show();
        });

    }

    //Comment
    $scope.data.shouldShowCommentDelete = false;
    $scope.data.listCommentCanSwipe = true;

    $scope.data.noMoreCommentAvailable = true;
    $scope.commentIndex = 0;
    $scope.comments = [];
    var loadComment = function(_index, _nid, _flag) {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            hideOnStageChange: true,
            duration: CONSTANT_TIMEOUT
        });
        serviceComment.query({
            'parameters[nid]': _nid,
            page: _index,
            pagesize: 20
        }).$promise.then(function(results) {
            if (results.length != 0) {
                if (results.length < 20) $scope.data.noMoreCommentAvailable = true;
                else {
                    $scope.data.noMoreCommentAvailable = false;
                    $scope.commentIndex++;
                }
                var comments = results;
                if (_flag) {
                    $scope.comments = $scope.comments.concat(comments);
                } else $scope.comments = comments;
            } else {
                $scope.data.noMoreCommentAvailable = true;
            }
            $ionicLoading.hide();
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.loadMoreComments = function(_nid) {
        loadComment($scope.commentIndex, _nid, true);
    }

    $scope.openCommentModal = function(_workout, _flag, _index) { //_flag : true open the keyboard;
        $ionicModal.fromTemplateUrl('modal_2.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.modal_2 = modal;
            $scope.currentNID = _workout.nid;
            $scope.currentIndex = _index;
            $scope.currentUID = _workout.uid;
            $scope.currentUsername = _workout.name;
            loadComment($scope.commentIndex, _workout.nid, false);
            $scope.modal_2.show();
        });
    }

    $scope.deleteComment = function(_index, _type) {
        var _cid = $scope.comments[_index].cid;
        serviceComment.remove({
            id: _cid
        }).$promise.then(function(results) {
            if (results[0]) {
                $scope.comments.splice(_index, 1);
                if (_type) { //fav
                    $scope.favouriteList[$scope.currentIndex].comment_count--;
                } else {
                    $scope.data.workoutlist[$scope.currentIndex].comment_count--;
                }
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.sendComment = function(_msg) {
        var _comment = {
            "nid": $scope.currentNID,
            "name": userName,
            "comment_body": {
                "und": [{
                    "value": _msg
                }]
            }
        }
        serviceComment.post(_comment).$promise.then(function(results) {
            $scope.comments = $scope.comments.concat(results);
            if ($scope.data.type) { //fav
                $scope.favouriteList[$scope.currentIndex].comment_count++;
                $scope.favouriteList[$scope.currentIndex].commented = true;
            } else {
                $scope.data.workoutlist[$scope.currentIndex].comment_count++;
                $scope.data.workoutlist[$scope.currentIndex].commented = true;
            }
            $scope.data.commentMessage = "";
            if (user.id != $scope.currentUID) {
                NotificationService.send(user.name, user.uid, $scope.currentUsername, $scope.currentUID, $scope.currentNID, 4);
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    $scope.closeModal = function(_id) {
        if (_id === 1) {
            $scope.modal_1.remove().then(function() {
                $scope.recommends = [];
                $scope.data.noMoreRecommendAvailable = true;
                $scope.recommendIndex = 0;
            });
        }
        if (_id === 2) {
            $scope.modal_2.remove().then(function() {
                $scope.comments = [];
                $scope.data.noMoreCommentAvailable = true;
                $scope.commentIndex = 0;
            });

        }
    }

    var favRecFunction = function(_nid, _action) {
        return $http.post(serviceUrl + '/node/' + _nid + '/' + _action, {}, {
            timeout: CONSTANT_TIMEOUT
        })
    }

    $scope.favouriteClick = function(_nid, _status, _index, _type) {
        if (_status == 0) { //action, favourite
            favRecFunction(_nid, 'favourite').then(function(response) {
                if (response.status == 200) {
                    if (_type) $scope.favouriteList[_index].favourite = 1;
                    else $scope.data.workoutlist[_index].favourite = 1;
                    NotificationHandler.favToast(0);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unfavourite
            favRecFunction(_nid, 'unfavourite').then(function(response) {
                if (response.status == 200) {
                    if (_type) $scope.favouriteList[_index].favourite = 0;
                    else $scope.data.workoutlist[_index].favourite = 0;
                    NotificationHandler.favToast(1);
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.recommendClick = function(_workout, _index, _type) {
        var _nid = _workout.nid;
        var _status = _workout.recommend;
        if (_status == 0) { //action, recommend
            favRecFunction(_nid, 'recommend').then(function(response) {
                if (response.status == 200) {
                    if (_type) {
                        $scope.favouriteList[_index].recommend = 1;
                        $scope.favouriteList[_index].recommends++;
                    } else {
                        $scope.data.workoutlist[_index].recommend = 1;
                        $scope.data.workoutlist[_index].recommends++;
                    }
                    if (user.uid != _workout.uid) {
                        NotificationService.send(user.name, user.uid, _workout.name, _workout.uid, _nid, 3);
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else if (_status == 1) { //action, unrecommend
            favRecFunction(_nid, 'unrecommend').then(function(response) {
                if (response.status == 200) {
                    if (_type) {
                        $scope.favouriteList[_index].recommend = 0;
                        if ($scope.favouriteList[_index].recommends != 0) $scope.favouriteList[_index].recommends--;
                        else $scope.favouriteList[_index].recommends = 0;
                    } else {
                        $scope.data.workoutlist[_index].recommend = 0;
                        if ($scope.data.workoutlist[_index].recommends != 0) $scope.data.workoutlist[_index].recommends--;
                        else $scope.data.workoutlist[_index].recommends = 0;
                    }
                }
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    var navTo = function(_uid) {
        console.log(_uid);
        if (_uid) {
            if (_uid == userId) {
                $state.go('tabs.myprofile')
            } else {
                $localStorage.fromfeed = "tabs.myprofile";
                $ionicHistory.clearCache();
                $state.go('visitorprofile', {
                    target: _uid
                });
            }
        }
    }

    $scope.navToProfile = function(_uid, _type) {
        if ($scope.workoutmodal) {
            $scope.workoutmodal.remove();
            if (!_type) {
                navTo(_uid);
            } else if (_type === 1) {
                $scope.modal_1.remove().then(function() {
                    navTo(_uid);
                });
            } else if (_type === 2) {
                $scope.modal_2.remove().then(function() {
                    navTo(_uid);
                });
            }
        }
        if ($scope.favouritemodal) {
            $scope.favouritemodal.remove();
            if (!_type) {
                navTo(_uid);
            } else if (_type === 1) {
                $scope.modal_1.remove().then(function() {
                    navTo(_uid);
                });
            } else if (_type === 2) {
                $scope.modal_2.remove().then(function() {
                    navTo(_uid);
                });
            }
        }
    };

    $scope.openFullImageModal = function(_url) {
        $ionicModal.fromTemplateUrl('templates/full_image_modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
        }).then(function(modal) {
            $scope.fullImageModal = modal;
            $scope.fullImage = _url;
            if (window.StatusBar) {
                StatusBar.hide();
            }
            $scope.fullImageModal.show();
        })
    };

    $scope.closeFullImageModal = function() {
        $scope.fullImageModal.hide();
        if (window.StatusBar) {
            StatusBar.show();
        }
    };

    $scope.$on('$destory', function() {
        $scope.fullImageModal.remove();
        if ($scope.reportModal) $scope.reportModal.remove();
    })

    $scope.rowClass = function(exercise_index, set_index, subset_length) {
        return workoutStyle.rowClass(exercise_index, set_index, subset_length);
    };
    $scope.headClass = function(exercise_index, exercises_length) {
        return workoutStyle.headClassExercise(exercise_index, exercises_length);
    };

    $scope.rowClassFirst = function(exercise_index, set_index, workout_set) {
        return workoutStyle.rowClassFirst(exercise_index, set_index, workout_set);
    };

    $scope.widthFn = function(display_type, position) {
        return workoutStyle.widthFn(display_type, position);
    };

    $scope.tableStyle = function(_index, _length) {
        return workoutStyle.tableStyle(_index, _length);
    };
});

app.controller('MyFollowingCtrl', function($scope, $http, $localStorage, ErrorHandler, $state, $cordovaProgress, $ionicHistory, Constants, $stateParams, serviceUser, UserDataService, $cordovaToast) {
    var serviceUrl = Constants.API.serviceUrl;
    var user = $localStorage.loginuser;
    var CONSTANT_TIMEOUT = Constants.timeout;
    var userId = user.uid;
    var followingIndex = 0;

    $scope.navBackTo = function() {
        $state.go('tabs.myprofile');
    }

    $scope.followings = [];
    $scope.noMoreFollowingAvailable = true;
    var loadFollowing = function(_index, _uid, _type, _flag) {
        $http.post(serviceUrl + "/user/" + _uid + "/" + _type + "/" + _index, {}, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.noMoreFollowingAvailable = true;
                else {
                    $scope.noMoreFollowingAvailable = false;
                    followingIndex++;
                }
                if (_flag) $scope.followings = $scope.followings.concat(response.data);
                else $scope.followings = response.data
            } else {
                $scope.noMoreFollowingAvailable = true;
            }
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }
    loadFollowing(followingIndex, userId, 'following', false);

    $scope.loadMoreFollowings = function() {
        loadFollowing(followingIndex, userId, 'following', true);
    }

    $scope.navTo = function(_uid) {
        //$ionicHistory.clearHistory();
        $state.go('otherprofile', {
            target: _uid
        }, {
            reload: true
        });
    }
});

app.controller('MyFollowersCtrl', function($scope, $http, $state, ErrorHandler, $localStorage, $cordovaProgress, $ionicHistory, Constants, $stateParams, serviceUser, UserDataService, $cordovaToast) {
    //var _visitor_id = $localStorage.vistor_id;
    var serviceUrl = Constants.API.serviceUrl;
    var user = $localStorage.loginuser;
    var CONSTANT_TIMEOUT = Constants.timeout;
    var userId = user.uid;
    var followerIndex = 0;

    $scope.navBackTo = function() {
        $state.go('tabs.myprofile');
    }

    $scope.followers = [];

    $scope.noMoreFollowerAvailable = true;


    var loadFollower = function(_index, _uid, _type, _flag) {
        $http.post(serviceUrl + "/user/" + _uid + "/" + _type + "/" + _index, {}, {
            timeout: CONSTANT_TIMEOUT
        }).then(function(response) {
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.noMoreFollowerAvailable = true;
                else {
                    $scope.noMoreFollowerAvailable = false;
                    followerIndex++;
                }
                if (_flag) $scope.followers = $scope.followers.concat(response.data);
                else $scope.followers = response.data;
            } else {
                $scope.noMoreFollowerAvailable = true;
            }
            console.log($scope.noMoreFollowerAvailable);
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }

    loadFollower(followerIndex, userId, 'follower', false);

    $scope.loadMoreFollowers = function() {
        loadFollower(followerIndex, userId, 'follower', true);
    }

    $scope.navTo = function(_uid) {
        //$ionicHistory.clearHistory();
        $state.go('otherprofile', {
            target: _uid
        });
    }
});