'use strict'

var app = angular.module('controllers.setting', ['ionic']);
app.controller('SettingsHelpCtrl', function($scope, $http, $state, $localStorage, $ionicLoading, $ionicModal, Constants, $cordovaActionSheet, $stateParams, $cordovaContacts, $cordovaSms, NotificationHandler) {
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    var user = $localStorage.loginuser;
    var userId = user.uid;
    //console.log(appVersion);
    //
    $ionicModal.fromTemplateUrl('templates/settings/contacts.html', {
        scope: $scope,
        animation: 'slide-in-up'
    }).then(function(modal) {
        $scope.contactModal = modal;
    });

    $scope.getContacts = function() {
        $scope.phoneContacts = [];
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            duration: CONSTANT_TIMEOUT
        });

        function onSuccess(contacts) {
            $ionicLoading.hide();
            for (var i = 0; i < contacts.length; i++) {
                var contact = contacts[i];
                $scope.phoneContacts.push(contact);
            }
            $scope.contactModal.show();
        };

        function onError(contactError) {
            $ionicLoading.hide();
            alert(contactError);
        };
        var options = {};
        options.multiple = true;
        $cordovaContacts.find(options).then(onSuccess, onError);
    };

    $scope.sendMessage = function(_name, _phone_numbers) {
        var options = {
            replaceLineBreaks: false, // true to replace \n by a new line, false by default
            android: {
                intent: 'INTENT' // send SMS with the native android SMS messaging
                //intent: '' // send SMS without open any other app
            }
        };
        var _phone_number = _phone_numbers[0];
        if (_phone_number.type === 'mobile') {
            NotificationHandler.confirm('Send message to join the Gymstar', 'Tell a friend').then(function(btnIndex) {
                if (btnIndex === 2) { //confirm send
                    console.log(_phone_number);
                    $cordovaSms
                        .send(_phone_number.value, 'have you seen this new gym app?', options)
                        .then(function() {
                            NotificationHandler.alert('Message sent successfully');
                        }, function(error) {
                            NotificationHandler.alert(error);
                        });
                }
            });
        } else {
            NotificationHandler.alert('The number is not mobile phone number');
        }
    };

    $scope.sendMessages = function() { //contact.name.formatted, contact.phoneNumbers
        var options = {
            replaceLineBreaks: false, // true to replace \n by a new line, false by default
            android: {
                intent: 'INTENT' // send SMS with the native android SMS messaging
                    //intent: '' // send SMS without open any other app
            }
        };
        var _contacts = [];
        angular.forEach($scope.phoneContacts, function(_contact) {
            if (_contact.checked) {
                var _phone_number = _contact.phoneNumbers[0].value;
                //var _name = _contact.name.formatted;
                this.push(_phone_number);
            }
        }, _contacts);

        if (_contacts.length == 0) {
            NotificationHandler.alert('please select as least one friend to send message.');
        } else {
            _contacts = _contacts.join();
            $cordovaSms.send(_contacts, 'have you seen this new gym app?', options)
                .then(function() {
                    NotificationHandler.alert('Message sent successfully');
                }, function(error) {
                    NotificationHandler.alert(error);
                });
        }

    };
    $scope.closeContactModal = function() {
        $scope.contactModal.hide();
    };
});


app.controller('SettingsChatCtrl', function($scope, $localStorage, $ionicHistory, $http, $ionicLoading, Constants, NotificationHandler) {
    
    var CONSTANT_TIMEOUT=Constants.timeout;

    $scope.clearChat = function() {
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            duration: CONSTANT_TIMEOUT
        });
        $http.post(Constants.API.serviceUrl + "/user/" + $localStorage.loginuser.uid + "/reset_chat", {}, {timeout:CONSTANT_TIMEOUT}).then(function(response) {
            $ionicLoading.hide();
            $localStorage.team_message = [];
            var _d=new Date();
            $localStorage.loginuser.clearChatDate = _d.getTime();
            $ionicHistory.clearCache();
            NotificationHandler.success("Cleared!");
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }
});

app.controller('SettingsAccountCtrl', function($scope, $http, $state, AuthService, $ionicLoading, $timeout, $localStorage, ImageService, ErrorHandler, $cordovaProgress, $ionicHistory, Constants, serviceUser, workoutService) {
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    var user = $localStorage.loginuser;
    var userId = user.uid;
    $scope.data = {};
    $scope.user = angular.copy(user);
    $scope.unitChanged = false;

    var savePrivacy = function() {
        if ($scope.user.privacy != user.privacy) {
            $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration:CONSTANT_TIMEOUT
            });
            var _user = {};

            _user["field_privacy"] = {
                'und': {
                    '0': {
                        'value': $scope.user.privacy
                    }
                }

            };

            serviceUser.update({
                id: userId
            }, _user).$promise.then(function(user) {
                $ionicLoading.hide();
                $cordovaProgress.showSuccess(true, "Success!");
                $timeout(function() {
                    $cordovaProgress.hide();
                }, 1000);
                AuthService.logout();
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });

        }
    }

    var saveUnit = function() {
        if ($scope.unitChanged) {
            $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration: CONSTANT_TIMEOUT
            });
            var _user = {};

            var _distance="";
            if($scope.user.distanceUnit=="km")  _distance="m/km";
            else _distance="mile";
            _user["field_weight_unit"] = {
                'und': {
                    '0': {
                        'value': $scope.user.weightUnit
                    }
                }

            };
            _user["field_distance_unit"] = {
                'und': {
                    '0': {
                        'value': _distance
                    }
                }

            };
            _user["field_height_unit"] = {
                'und': {
                    '0': {
                        'value': $scope.user.heightUnit
                    }
                }

            };

            serviceUser.update({
                id: userId
            }, _user).$promise.then(function(user) {
                $ionicLoading.hide();
                $cordovaProgress.showSuccess(true, "Success!");
                $timeout(function() {
                    $cordovaProgress.hide();
                }, 1000);
                var _user = $localStorage.loginuser;
                _user["weightUnit"] = user["field_weight_unit"]["und"]["0"]["value"];;
                _user["distanceUnit"] = user["field_distance_unit"]["und"]["0"]["value"];;
                _user["heightUnit"] = user["field_height_unit"]["und"]["0"]["value"];;
                $localStorage.loginuser = _user;
                delete $localStorage.workoutlist;
                workoutService.setUnit(_user["weightUnit"], _user["distanceUnit"]);
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    var savePassword = function() {
        if ($scope.data.password == $scope.data.password_confirm) {
            $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration:CONSTANT_TIMEOUT
            });
            var _user = {};

            _user["pass"] = $scope.data.password;
            _user['current_pass']=$scope.data.current_pass;
            serviceUser.update({
                id: userId
            }, _user).$promise.then(function(user) {
                $ionicLoading.hide();
                $cordovaProgress.showSuccess(true, "Success!");
                $timeout(function() {
                    $cordovaProgress.hide();
                }, 1000);
                AuthService.logout();

            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        } else {
            ErrorHandler.alertPopup('confirm password is not matched with password');
        }
    }

    $scope.save = function(_index) {
        switch (_index) {
            case 0:
                savePrivacy();
                break;
            case 1:
                saveUnit();
                break;
            case 2:
                savePassword();
                break;
            default:
                break;
        }
    }

    $scope.change = function(_index) {
        switch (_index) {
            case 0:
                $scope.privacyChanged = true;
                break;
            case 1:
                $scope.unitChanged = true;
                break;
            case 2:
                $scope.passworChanged = true;
                break;
            default:
                break;
        }
    }

    $scope.reset = function() {
        $scope.user = angular.copy(user);
    }
});

app.controller('SettingsBlockUserCtrl', function($scope, $http, $state, AuthService, $ionicLoading, $timeout, $localStorage, ImageService, ErrorHandler, $cordovaProgress, $ionicHistory, Constants, serviceUser, workoutService) {
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    var user = $localStorage.loginuser;
    var userId = user.uid;
    var blockuserIndex=0;
    $scope.data={};
    $scope.data.showDelete=false;
    $scope.blockusers = [];

    $scope.noMoreBlockUsersAvailable = true;

    var loadBlockUsers = function(_index, _uid, _flag) {
        $http.post(serviceUrl + "/user/" + _uid + "/blockusers/" + _index, {},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
            //console.log(response);
            if (response.data.length != 0) {
                if (response.data.length < 8) $scope.noMoreBlockUsersAvailable = true;
                else {
                    $scope.noMoreBlockUsersAvailable = false;
                    blockuserIndex++;
                }
                if (_flag) $scope.blockusers = $scope.blockusers.concat(response.data);
                else $scope.blockusers = response.data;
            } else {
                $scope.noMoreBlockUsersAvailable = true;
            }
            $scope.$broadcast('scroll.infiniteScrollComplete');
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }
    loadBlockUsers(blockuserIndex, userId, false);
    
    $scope.loadMoreBlockUsers = function() {
        loadBlockUsers(blockuserIndex, userId, true);
    }

    $scope.unblockUser=function(_tid, _index){
        $ionicLoading.show({
            template: '<ion-spinner icon="ios"></ion-spinner>',
            duration: CONSTANT_TIMEOUT
        });
        $http.post(serviceUrl + "/user/" + userId + "/unblock/" + _tid,{},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
            $ionicLoading.hide();
            if (response.data) {
                $scope.blockusers.splice(_index, 1);
            }
        }, function(err) {
            ErrorHandler.errorHandler(err);
        });
    }
});

app.controller('SettingsProfileCtrl', function($scope, $http, $state, $ionicLoading, $timeout, $localStorage, ImageService, ErrorHandler, $cordovaProgress, $ionicHistory, Constants, serviceUser, $jrCrop) {
    var user = $localStorage.loginuser;
    var userId = user.uid;
    var serviceUrl = Constants.API.serviceUrl;
    var CONSTANT_TIMEOUT=Constants.timeout;
    $scope.user = angular.copy(user);
    $scope.user.dob = new Date($scope.user.dob);
    $scope.countries = Constants.countryList;
    $scope.changed = false;
    var _tempPicturePath = $scope.user.picturePath;
    var imageData;

    $scope.pickPhoto = function() {
        ImageService.pickPhoto().then(function(btnIndex) {
            if (btnIndex == 1) {
                ImageService.takePhoto().then(function(_imageData) {
                    $jrCrop.crop({
                        url: "data:image/jpeg;base64," + _imageData,
                        width: window.innerWidth,
                        aspectRatio: 16 / 9,
                        scale: 1
                    }).then(function(canvas) {
                        var _dataURL = canvas.toDataURL();
                        $scope.user.picturePath = _dataURL;
                        imageData = _dataURL.split(',')[1];
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
            if (btnIndex == 2) {
                ImageService.choosePhoto().then(function(_imageData) {
                    $jrCrop.crop({
                        url: "data:image/jpeg;base64," + _imageData,
                        width: window.innerWidth,
                        aspectRatio: 16 / 9,
                        scale: 1
                    }).then(function(canvas) {
                        if (canvas != null) {
                            var _dataURL = canvas.toDataURL();
                            $scope.user.picturePath = _dataURL;
                            imageData = _dataURL.split(',')[1];
                        } else {
                            $cordovaToast.showShortCenter("Current Image is not supproted!");
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
        });
    }

    $scope.resetPicture = function() {
        user.picturePath = _tempPicturePath;
    }

    $scope.resetInfo = function() {
        $scope.user = angular.copy(user);
        $scope.user.dob = new Date($scope.user.dob);
    }

    $scope.change = function() {
        $scope.changed = true;
    }

    $scope.resetPB = function() {
        ErrorHandler.confirmPopup('Are you sure you want to reset the Personal Best?').then(function(res) {
            if (res == 1) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="ios"></ion-spinner>',
                    duration:CONSTANT_TIMEOUT
                });
                $http.post(serviceUrl + "/user/" + userId + "/reset_pb", {},{timeout:CONSTANT_TIMEOUT}).then(function(response) {
                    $ionicLoading.hide();
                    if (response.status = 200) {
                        $cordovaProgress.showSuccess(true, "Success!");
                        $timeout(function() {
                            $cordovaProgress.hide();
                        }, 1000);
                    }
                }, function(err) {
                    ErrorHandler.errorHandler(err);
                });
            }
        })
    }

    $scope.saveInfo = function() {
        if ($scope.changed) {
            $ionicLoading.show({
                template: '<ion-spinner icon="ios"></ion-spinner>',
                duration:CONSTANT_TIMEOUT
            });
            var _user = {};

            _user["field_name_first"] = {
                'und': {
                    '0': {
                        'value': $scope.user.firstname
                    }
                }
            };
            _user["field_name_last"] = {
                'und': {
                    '0': {
                        'value': $scope.user.lastname
                    }
                }
            };

            _user["field_real_name"] = {
                'und': {
                    '0': {
                        'value': $scope.user.firstname + " " + $scope.user.lastname
                    }
                }
            };

            _user["field_city_town"] = {
                'und': {
                    '0': {
                        'value': $scope.user.towncity
                    }
                }
            };

            _user["field_country"] = {
                'und': {
                    '0': {
                        'value': $scope.user.country
                    }
                }
            };


            _user["field_dob"] = {
                'und': {
                    '0': {
                        'value': {
                            'date': moment($scope.user.dob).format('YYYY-MM-DD')
                        }
                    }
                }
            };
            _user["field_gender"] = {
                'und': {
                    '0': {
                        'value': $scope.user.gender
                    }
                }

            };


            _user["field_hide_weight"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_weight
                    }
                }

            };


            _user["field_hide_height"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_height
                    }
                }

            };

            _user["field_hide_bmi"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_bmi
                    }
                }

            };


            _user["field_hide_body_fat"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_body_fat
                    }
                }

            };

            _user["field_hide_bpm"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_bpm
                    }
                }

            };

            _user["field_hide_age"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_age
                    }
                }

            };


            _user["field_hide_location"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_location
                    }
                }

            };

            _user["field_hide_gender"] = {
                'und': {
                    '0': {
                        'value': $scope.user.hide_gender
                    }
                }

            };

            
            serviceUser.update({
                id: userId
            }, _user).$promise.then(function(user) {
                $ionicLoading.hide();
                $cordovaProgress.showSuccess(true, "Success!");
                $timeout(function() {
                    $cordovaProgress.hide();
                }, 1000);
                var _user = $localStorage.loginuser;
                _user["firstname"] = user["field_name_first"]["und"]["0"]["value"];
                _user["lastname"] = user["field_name_last"]["und"]["0"]["value"];
                _user["name"] = user["field_real_name"]["und"]["0"]["value"];
                _user["towncity"] = user["field_city_town"]["und"]["0"]["value"];
                _user["country"] = user["field_country"]["und"]["0"]["value"];
                _user["dob"] = user["field_dob"]["und"]["0"]["value"];
                _user["gender"] = user["field_gender"]["und"]["0"]["value"];

                _user["hide_gender"]=user["field_hide_gender"]["und"]["0"]["value"];
                _user["hide_height"]=user["field_hide_height"]["und"]["0"]["value"];
                _user["hide_weight"]=user["field_hide_weight"]["und"]["0"]["value"];
                _user["hide_bmi"]=user["field_hide_bmi"]["und"]["0"]["value"];
                _user["hide_body_fat"]=user["field_hide_body_fat"]["und"]["0"]["value"];
                _user["hide_bpm"]=user["field_hide_bpm"]["und"]["0"]["value"];
                _user["hide_age"]=user["field_hide_age"]["und"]["0"]["value"];
                _user["hide_location"]=user["field_hide_location"]["und"]["0"]["value"];

                $localStorage.loginuser = _user;
            }, function(err) {
                ErrorHandler.errorHandler(err);
            });
        }
    }

    $scope.savePicture = function() {
        ImageService.postProfileImage(imageData, userId);
    }
});