'use strict';

angular.module('services.common.image', ['ionic', 'ngStorage'])
    .service('ImageService', ['$http', '$timeout', '$cordovaActionSheet', '$cordovaCamera', 'Constants', 'serviceFile', 'serviceUser', '$cordovaProgress', 'ErrorHandler', 'serviceTeam', '$ionicLoading',
        function($http, $timeout, $cordovaActionSheet, $cordovaCamera, Constants, serviceFile, serviceUser, $cordovaProgress, ErrorHandler, serviceTeam, $ionicLoading) {
            var CONSTANT_TIMEOUT = Constants.timeout;
            var image = {
                pickPhoto: function() {
                    var options = {
                        title: 'Choose photo from..',
                        buttonLabels: ['Camera', 'Photo Library'],
                        addCancelButtonWithLabel: 'Cancel',
                        androidEnableCancelButton: true,
                        winphoneEnableCancelButton: true
                    };
                    return $cordovaActionSheet.show(options).then(function(btnIndex) {
                        return btnIndex;
                    });

                    /*
                    return $ionicActionSheet.show({
                        buttons: [{
                            text: 'Camera'
                        }, {
                            text: 'Photo Library'
                        }],
                        destructiveText: 'Delete',
                        titleText: 'Choose photo from..',
                        cancelText: 'Cancel',
                        buttonClicked: function(index) {
                            return true;
                        }
                    });*/
                },
                choosePhoto: function() {
                    var options = {
                        quality: 30,
                        destinationType: Camera.DestinationType.DATA_URL,
                        sourceType: Camera.PictureSourceType.PHOTOLIBRARY,
                        allowEdit: false,
                        encodingType: Camera.EncodingType.JPEG,
                        //targetWidth: 720,
                        //targetWidth: 480,
                        //targetHeight: 270,
                        mediaType: 0, //set to photo only
                        correctOrientation: true,
                        //popoverOptions: CameraPopoverOptions,
                        saveToPhotoAlbum: false
                    };

                    return $cordovaCamera.getPicture(options);
                },
                takePhoto: function() {
                    var options = {
                        quality: 30,
                        destinationType: Camera.DestinationType.DATA_URL,
                        sourceType: Camera.PictureSourceType.CAMERA,
                        //targetWidth: 720,
                        allowEdit: false,
                        encodingType: Camera.EncodingType.JPEG,
                        correctOrientation: true,
                        //popoverOptions: CameraPopoverOptions,
                        saveToPhotoAlbum: true
                    };
                    return $cordovaCamera.getPicture(options);
                },
                postImage: function(imageData, userId, teamName, teamId) {
                    $ionicLoading.show({
                        template: '<ion-spinner icon="ios"></ion-spinner> <p>Saving...</p>',
                        hideOnStageChange: true,
                        duration: CONSTANT_TIMEOUT
                    });
                    var imagePost = {};
                    var timestamp = new Date().getTime();
                    imagePost['uid'] = userId;
                    imagePost['file'] = imageData;
                    imagePost['filesize'] = imageData.length;
                    imagePost['filename'] = "team_" + teamName + "_" + userId + "_" + timestamp + ".jpg";
                    $http.post(Constants.API.fileUrl, imagePost, {
                        timeout: CONSTANT_TIMEOUT
                    }).success(function(data, status, headers, config) {
                        if (status == 200) {
                            serviceFile.get({
                                id: data.fid
                            }, function(file) {
                                var _obj = file;
                                delete _obj.uri_full;
                                delete _obj.target_uri;
                                delete _obj.file;
                                delete _obj.image_styles;
                                var _picture = {};

                                _picture["field_team_picture"] = {
                                    'und': {
                                        '0': _obj
                                    }
                                };

                                serviceTeam.update({
                                    id: teamId
                                }, _picture).$promise.then(function(user) {
                                    $ionicLoading.hide();
                                    $cordovaProgress.showSuccess(true, "Success!");
                                    $timeout(function() {
                                        $cordovaProgress.hide();
                                    }, 1000);
                                }, function(err) {
                                    ErrorHandler.errorHandler(err);
                                });
                            }, function(err) {
                                ErrorHandler.errorHandler(err);
                            });
                        } else {
                            $ionicLoading.hide();
                            $cordovaToast.showShortCenter("Failed!");
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                },
                postProfileImage: function(imageData, userId) {
                    $ionicLoading.show({
                        template: '<ion-spinner icon="ios"></ion-spinner> <p>Saving...</p>',
                        hideOnStageChange: true,
                        duration: CONSTANT_TIMEOUT
                    });
                    var imagePost = {};
                    var timestamp = new Date().getTime();
                    imagePost['uid'] = userId;
                    imagePost['file'] = imageData;
                    imagePost['filesize'] = imageData.length;
                    imagePost['filename'] = "profile_" + userId + "_" + timestamp + ".jpg";
                    $http.post(Constants.API.fileUrl, imagePost, {
                        timeout: CONSTANT_TIMEOUT
                    }).success(function(data, status, headers, config) {
                        if (status == 200) {
                            serviceFile.get({
                                id: data.fid
                            }, function(file) {
                                var _obj = file;
                                delete _obj.uri_full;
                                delete _obj.target_uri;
                                delete _obj.file;
                                delete _obj.image_styles;
                                var _picture = {};
                                _picture["field_profile"] = {
                                    'und': {
                                        '0': _obj
                                    }
                                };
                                serviceUser.update({
                                    id: userId
                                }, _picture).$promise.then(function(user) {
                                    $ionicLoading.hide();
                                    $cordovaProgress.showSuccess(true, "Success!");
                                    $timeout(function() {
                                        $cordovaProgress.hide();
                                    }, 1000);
                                    var _user = $localStorage.loginuser;
                                    _user["field_profile"] = user["field_profile"];
                                    $localStorage.loginuser = _user;
                                }, function(err) {
                                    ErrorHandler.errorHandler(err);
                                });
                            }, function(err) {
                                ErrorHandler.errorHandler(err);
                            });
                        } else {
                            $ionicLoading.hide();
                            $cordovaToast.showShortCenter("Failed!");
                        }
                    }, function(err) {
                        ErrorHandler.errorHandler(err);
                    });
                }
            }
            return image;
        }
    ]).service('TeamService', ['$localStorage', function($http, $localStorage) {
        var _team = {};
        var _postImage = {};
        var team = {
            setTeam: function(_t) {
                _team = _t;
            },
            getTeam: function() {
                return _team;
            },
            resetTeam: function() {
                _team = {};
                _postImage = {};
            },
            setImage: function(_i) {
                _postImage = _i;
            },
            getImage: function() {
                return _postImage;
            }
        }
        return team;
    }]);